@@ -176,6 +176,139 @@ with that number. In addition, the sender must save outbound messages even
 after they have been delivered over the transport, until the sender receives
 a next-expected-sequence higher than the outbound message. The details of
 this logic are described in L{landscape.broker.store}.
+
+Exchange Sequence
+=================
+
+Diagram::
+
+  1. BrokerService    -->  MessageExchange               : Start
+
+  2. MessageExchange  -->  MessageExchange               : Schedule exchange
+
+  3. [event]          <--  MessageExchange               : Fire "pre-exchange"
+
+  4. [optional]                                          : Do registration
+     (See L{landscape.broker.registration})              : sequence
+
+  5. MessageExchange  -->  MessageStore                  : Request pending
+                                                         : messages
+
+  6. MessageExchange  <--  MessageStore                  : return( Messages )
+
+  7. MessageExchange  -->  HTTPTransport                 : Exchange
+
+  8. HTTPTransport    -->  {Server}LandscapeMessageSystem
+                                                         : HTTP POST
+
+  9. [Scope: Server]
+   |
+   |   9.1 LandscapeMessageSystem --> ComputerMessageAPI : run
+   |
+   |   9.2 ComputerMessageAPI     --> FunctionHandler    : handle
+   |
+   |   9.3 FunctionHandler        --> Callable           : call
+   |       ( See also server code at:
+   |             - C{canonical.landscape.message.handlers}
+   |             - C{canonical.message.handler.FunctionHandler} )
+   |
+   |
+   |   9.4 [If: the callable raises ConsistencyError]
+   |     |
+   |     | 9.4.1 ComputerMessageAPI --> Computer         : request
+   |     |                                               : Resynchronize
+   |     |
+   |     | 9.4.2 Computer           --> Computer         : Create
+   |     |                                               : ResynchronizeRequest
+   |     |                                               : activity
+   |     |
+   |     --[End If]
+   |
+   |  9.5 ComputerMessageAPI     --> Computer            : get deliverable
+   |                                                     : activities
+   |
+   |  9.6 ComputerMessageAPI     <-- Computer            : return activities
+   |
+   |  9.7 [Loop over activities]
+   |    |
+   |    | 9.7.1 ComputerMessageAPI  --> Activity         : deliver
+   |    |
+   |    | 9.7.2 Activity            --> MessageStore     : add activity message
+   |    |
+   |    --[End Loop]
+   |
+   |  9.8 ComputerMessageAPI     --> MessageStore        : get pending messages
+   |
+   |  9.9 ComputerMessageAPI     <-- MessageStore        : return messages
+   |
+   | 9.10 LandscapeMessageSystem <-- ComputerMessageAPI  : return payload
+   |                                                     : (See below)
+   |
+   -- [End Scope]
+
+  10. HTTPTransport    <--  {Server}LandscapeMessageSystem
+                                                         : HTTP response
+                                                         : with payload
+
+  11. MessageExchange  <--  HTTPTransport                : response
+
+  12. [If: server says it expects a very old message]
+   |
+   |  12.1 [event]              <-- MessageExchange      : event
+   |       (See L{landscape.broker.server})              : "resynchronize-
+   |                                                     : clients"
+   |
+   -- [End if]
+
+  13. [Loop: over messages in payload]
+   |
+   |  13.1 [event]             <-- MessageExchange       : event
+   |                                                     : message (message)
+   |
+   |  13.2 [Switch: on message type]
+   |     |
+   |     |- 13.2.1 [Case: message type is "accepted-types"]
+   |     |       |
+   |     |       | 13.2.1.1 MessageExchange -> MessageStore
+   |     |       |                                       : set accepted types
+   |     |       |
+   |     |       | 13.2.1.2 MessageExchange -> MessageExchange
+   |     |       |                                       : schedule urgent
+   |     |       |                                       : exchange
+   |     |       --[End Case]
+   |     |
+   |     |- 13.2.2 [Case: message type is "resynchronize"]
+   |     |       |
+   |     |       | 13.2.2.1 [event]         <- MessageExchange
+   |     |       |        (See L{landscape.broker.server})
+   |     |       |                                      : event
+   |     |       |                                      : "resynchronize-
+   |     |       |                                      : clients"
+   |     |       |
+   |     |       | 13.2.2.2 MessageExchange -> MessageStore
+   |     |       |                                      : add "resynchronize"
+   |     |       |                                      : message
+   |     |       |
+   |     |       | 13.2.2.3 MessageExchange -> MessageExchange
+   |     |       |                                      : schedule urgent
+   |     |       |                                      : exchange
+   |     |       |
+   |     |       --[End Case]
+   |     |
+   |     |- 13.2.3 [Case: message type is "set-intervals"]
+   |     |       |
+   |     |       | 13.2.3.1 MessageExchange -> BrokerConfiguration
+   |     |       |                                      : set exchange
+   |     |       |                                      : interval
+   |     |       |
+   |     |       --[End Case]
+   |     |
+   |     -- [End Switch]
+   |
+   -- [End Loop]
+
+  14. Schedule exchange
+
 """
 import time
 import logging
@@ -328,10 +461,15 @@ class MessageExchange(object):
 
     def _handle_resynchronize(self, message):
         opid = message["operation-id"]
+        scopes = message.get("scopes")
         self.send({"type": "resynchronize", "operation-id": opid})
-        self._reactor.fire("resynchronize-clients")
+        self._reactor.fire("resynchronize-clients", scopes=scopes)
 
-    def _resynchronize(self):
+    def _resynchronize(self, scopes=None):
+        # When re-synchronisation occurs we don't want any previous messages
+        # being sent to the server, dropping the existing session_ids means
+        # that messages sent with those IDs will be dropped by the broker.
+        self._message_store.drop_session_ids(scopes)
         self.schedule_exchange(urgent=True)
 
     def _handle_set_intervals(self, message):
@@ -375,6 +513,13 @@ class MessageExchange(object):
 
         deferred = Deferred()
 
+        def exchange_completed():
+            self.schedule_exchange(force=True)
+            self._reactor.fire("exchange-done")
+            logging.info("Message exchange completed in %s.",
+                         format_delta(time.time() - start_time))
+            deferred.callback(None)
+
         def handle_result(result):
             self._exchanging = False
             if result:
@@ -382,17 +527,20 @@ class MessageExchange(object):
                     logging.info("Switching to normal exchange mode.")
                     self._urgent_exchange = False
                 self._handle_result(payload, result)
+                self._message_store.record_success(int(self._reactor.time()))
             else:
                 self._reactor.fire("exchange-failed")
                 logging.info("Message exchange failed.")
+            exchange_completed()
 
-            self.schedule_exchange(force=True)
-            self._reactor.fire("exchange-done")
-            logging.info("Message exchange completed in %s.",
-                         format_delta(time.time() - start_time))
-            deferred.callback(None)
+        def handle_failure(failure_type, failure_value, failure_tb):
+            self._exchanging = False
+            self._reactor.fire("exchange-failed")
+            self._message_store.record_failure(int(self._reactor.time()))
+            logging.info("Message exchange failed.")
+            exchange_completed()
 
-        self._reactor.call_in_thread(handle_result, None,
+        self._reactor.call_in_thread(handle_result, handle_failure,
                                      self._transport.exchange, payload,
                                      self._registration_info.secure_id,
                                      self._get_exchange_token(),
@@ -441,8 +589,8 @@ class MessageExchange(object):
             self._notification_id = self._reactor.call_later(
                 notification_interval, self._notify_impending_exchange)
 
-            self._exchange_id = self._reactor.call_later(interval,
-                                                         self.exchange)
+            self._exchange_id = self._reactor.call_later(
+                interval, self.exchange)
 
     def _get_exchange_token(self):
         """Get the token given us by the server at the last exchange.
