@@ -35,7 +35,7 @@ would like::
 
     (next-expected-sequence: 4)
 
-meaning that the peer as received all the three messages that we sent, an so
+meaning that the peer has received all the three messages that we sent, and so
 the next message it expects to receive is the one identified by the number 4.
 At this point we update both our pending offset and our sequence values, and
 the store now looks like::
@@ -92,12 +92,13 @@ system and L{landscape.lib.message.got_next_expected} to check how the
 strategy for updating the pending offset and the sequence is implemented.
 """
 
-import time
 import itertools
 import logging
 import os
+import uuid
 
 from landscape.lib import bpickle
+from landscape.lib.fs import create_file
 from landscape import SERVER_API
 
 
@@ -125,9 +126,7 @@ class MessageStore(object):
 
     api = SERVER_API
 
-    def __init__(self, persist, directory, directory_size=1000,
-                 get_time=time.time):
-        self._get_time = get_time
+    def __init__(self, persist, directory, directory_size=1000):
         self._directory = directory
         self._directory_size = directory_size
         self._schemas = {}
@@ -286,14 +285,44 @@ class MessageStore(object):
                 i += 1
         return False
 
+    def record_success(self, timestamp):
+        """Record a successful exchange."""
+        self._persist.remove("first-failure-time")
+        self._persist.remove("blackhole-messages")
+
+    def record_failure(self, timestamp):
+        """
+        Record a failed exchange, if all exchanges for the past week have
+        failed then blackhole any future ones and request a full re-sync.
+        """
+        if not self._persist.has("first-failure-time"):
+            self._persist.set("first-failure-time", timestamp)
+        continued_failure_time = timestamp - self._persist.get(
+            "first-failure-time")
+        if self._persist.get("blackhole-messages"):
+            # Already added the resync message
+            return
+        if continued_failure_time > (60 * 60 * 24 * 7):
+            # reject all messages after a week of not exchanging
+            self.add({"type": "resynchronize"})
+            self._persist.set("blackhole-messages", True)
+            logging.warning(
+                "Unable to succesfully communicate with Landscape server "
+                "for more than a week. Waiting for resync.")
+
     def add(self, message):
         """Queue a message for delivery.
 
         @param message: a C{dict} with a C{type} key and other keys conforming
-            to the L{Message} schema for that specifc message type.
-        @return: message_id, which is an identifier for the added message.
+            to the L{Message} schema for that specific message type.
+
+        @return: message_id, which is an identifier for the added
+                 message or C{None} if the message was rejected.
         """
         assert "type" in message
+        if self._persist.get("blackhole-messages"):
+            logging.debug("Dropped message, awaiting resync.")
+            return
         message = self._schemas[message["type"]].coerce(message)
 
         if "api" not in message:
@@ -302,11 +331,9 @@ class MessageStore(object):
         message_data = bpickle.dumps(message)
 
         filename = self._get_next_message_filename()
-
-        file = open(filename + ".tmp", "w")
-        file.write(message_data)
-        file.close()
-        os.rename(filename + ".tmp", filename)
+        temp_path = filename + ".tmp"
+        create_file(temp_path, message_data)
+        os.rename(temp_path, filename)
 
         if not self.accepts(message["type"]):
             filename = self._set_flags(filename, HELD)
@@ -345,8 +372,8 @@ class MessageStore(object):
     def _walk_pending_messages(self):
         """Walk the files which are definitely pending."""
         pending_offset = self.get_pending_offset()
-        for i, filename in enumerate(self._walk_messages(exclude=HELD +
-                                                                 BROKEN)):
+        for i, filename in enumerate(
+                self._walk_messages(exclude=HELD + BROKEN)):
             if i >= pending_offset:
                 yield filename
 
@@ -421,6 +448,49 @@ class MessageStore(object):
     def _add_flags(self, path, flags):
         self._set_flags(path, self._get_flags(path) + flags)
 
+    def get_session_id(self, scope=None):
+        """Generate a unique session identifier, persist it and return it.
+
+        See also L{landscape.broker.server.BrokerServer.get_session_id} for
+        more information on what this is used for.
+
+        @param scope: A string identifying the scope of interest of requesting
+            object. Currently this is unused but it has been implemented in
+            preparation for a fix for bug #300278 so that we don't have to
+            change the persisted structure later.  When that fix is in place
+            this will allow us to re-synchronise only certain types of
+            information, limited by scope.
+        """
+        session_ids = self._persist.get("session-ids", {})
+        for session_id, stored_scope in session_ids.iteritems():
+            # This loop should be relatively short as it's intent is to limit
+            # session-ids to one per scope.  The or condition here is not
+            # strictly necessary, but we *should* do "is" comparisons when we
+            # can (so says PEP 8).
+            if scope is stored_scope or scope == stored_scope:
+                return session_id
+        session_id = str(uuid.uuid4())
+        session_ids[session_id] = scope
+        self._persist.set("session-ids", session_ids)
+        return session_id
+
+    def is_valid_session_id(self, session_id):
+        """
+        Returns L{True} if the provided L{session_id} is known by this
+        L{MessageStore}.
+        """
+        return session_id in self._persist.get("session-ids", {})
+
+    def drop_session_ids(self, scopes=None):
+        """Drop all session ids."""
+        new_session_ids = {}
+        if scopes:
+            session_ids = self._persist.get("session-ids", {})
+            for session_id, session_scope in session_ids.iteritems():
+                if session_scope not in scopes:
+                    new_session_ids[session_id] = session_scope
+        self._persist.set("session-ids", new_session_ids)
+
 
 def get_default_message_store(*args, **kwargs):
     """
