@@ -10,7 +10,18 @@ from landscape.broker.store import MessageStore
 from landscape.broker.ping import Pinger
 from landscape.broker.registration import RegistrationHandler
 from landscape.tests.helpers import (LandscapeTest, DEFAULT_ACCEPTED_TYPES)
+from landscape.tests.mocker import MATCH
 from landscape.broker.tests.helpers import ExchangeHelper
+from landscape.broker.server import BrokerServer
+
+
+class RaisingTransport(object):
+
+    def get_url(self2):
+        return ""
+
+    def exchange(self2, *args):
+        raise RuntimeError("Failed to communicate.")
 
 
 class MessageExchangeTest(LandscapeTest):
@@ -40,6 +51,56 @@ class MessageExchangeTest(LandscapeTest):
         self.reactor.fire("resynchronize-clients")
         self.assertTrue(self.exchanger.is_urgent())
 
+    def test_that_resynchronize_drops_session_ids(self):
+        """
+        When a resynchronisation event occurs with global scope all existing
+        session IDs are expired, so any new messages being sent with those IDs
+        will be discarded.
+        """
+        broker = BrokerServer(self.config, self.reactor,
+                              self.exchanger, None,
+                              self.mstore, None)
+
+        disk_session_id = self.mstore.get_session_id(scope="disk")
+        package_session_id = self.mstore.get_session_id(scope="package")
+        self.mstore.set_accepted_types(["empty"])
+        global_scope = []
+        self.reactor.fire("resynchronize-clients", global_scope)
+        broker.send_message({"type": "empty"}, disk_session_id)
+        broker.send_message({"type": "empty"}, package_session_id)
+        self.exchanger.exchange()
+        messages = self.transport.payloads[0]["messages"]
+        self.assertMessages(messages, [])
+
+    def test_that_resynchronize_drops_scoped_session_ids_only(self):
+        """
+        When a resynchronisation event occurs with a scope existing session IDs
+        for that scope are expired, all other session IDs are unaffected.
+        """
+        broker = BrokerServer(self.config, self.reactor,
+                              self.exchanger, None,
+                              self.mstore, None)
+
+        disk_session_id = self.mstore.get_session_id(scope="disk")
+        package_session_id = self.mstore.get_session_id(scope="package")
+        self.mstore.set_accepted_types(["empty"])
+        disk_scope = ["disk"]
+        self.reactor.fire("resynchronize-clients", disk_scope)
+        broker.send_message({"type": "empty"}, disk_session_id)
+        broker.send_message({"type": "empty"}, package_session_id)
+        self.exchanger.exchange()
+        messages = self.transport.payloads[0]["messages"]
+        self.assertMessages(messages, [{"type": "empty"}])
+
+    def test_that_resynchronize_clears_message_blackhole(self):
+        """
+        When a resynchronisation event occurs the block on new messages
+        being stored is lifted.
+        """
+        self.reactor.fire("resynchronize-clients", [])
+        persist = Persist(filename=self.persist_filename)
+        self.assertFalse(persist.get("blackhole-messages"))
+
     def test_send(self):
         """
         The send method should cause a message to show up in the next exchange.
@@ -95,7 +156,7 @@ class MessageExchangeTest(LandscapeTest):
         represents the types that we think the server wants.
         """
         payload = self.exchanger._make_payload()
-        self.assertTrue("accepted-types" in payload)
+        self.assertIn("accepted-types", payload)
         self.assertEqual(payload["accepted-types"], md5("").digest())
 
     def test_handle_message_sets_accepted_types(self):
@@ -128,7 +189,7 @@ class MessageExchangeTest(LandscapeTest):
         self.exchanger.handle_message(
             {"type": "accepted-types", "types": ["ack", "bar"]})
         payload = self.exchanger._make_payload()
-        self.assertTrue("accepted-types" in payload)
+        self.assertIn("accepted-types", payload)
         self.assertEqual(payload["accepted-types"],
                          md5("ack;bar").digest())
 
@@ -308,6 +369,21 @@ class MessageExchangeTest(LandscapeTest):
         self.wait_for_exchange(urgent=True)
         self.assertEqual(len(self.transport.payloads), 1)  # no change
 
+    def test_successful_exchange_records_success(self):
+        """
+        When a successful exchange occurs, that success is recorded in the
+        message store.
+        """
+        mock_message_store = self.mocker.proxy(self.mstore)
+        mock_message_store.record_success(MATCH(lambda x: type(x) is int))
+        self.mocker.result(None)
+        self.mocker.replay()
+
+        exchanger = MessageExchange(
+            self.reactor, mock_message_store, self.transport,
+            self.identity, self.exchange_store, self.config)
+        exchanger.exchange()
+
     def test_ancient_causes_resynchronize(self):
         """
         If the server asks for messages that we no longer have, the message
@@ -325,7 +401,7 @@ class MessageExchangeTest(LandscapeTest):
         # the server loses some data
         self.transport.next_expected_sequence = 0
 
-        def resynchronize():
+        def resynchronize(scopes=None):
             # We'll add a message to the message store here, since this is what
             # is commonly done in a resynchronize callback. This message added
             # should come AFTER the "resynchronize" message that is generated
@@ -345,12 +421,12 @@ class MessageExchangeTest(LandscapeTest):
         """
         If a message of type 'resynchronize' is received from the
         server, the exchanger should *first* send a 'resynchronize'
-        message back to the server and *then* fire a 'resynchronize-clients'
-        event.
+        message back to the server and *then* fire a
+        'resynchronize-clients' event.
         """
         self.mstore.set_accepted_types(["empty", "resynchronize"])
 
-        def resynchronized():
+        def resynchronized(scopes=None):
             self.mstore.add({"type": "empty"})
         self.reactor.call_on("resynchronize-clients", resynchronized)
 
@@ -362,6 +438,25 @@ class MessageExchangeTest(LandscapeTest):
                               "operation-id": 123},
                              {"type": "empty"}])
 
+    def test_scopes_are_copied_from_incoming_resynchronize_messages(self):
+        """
+        If an incoming message of type 'reysnchronize' contains a 'scopes' key,
+        then it's value is copied into the "resynchronize-clients" event.
+        """
+        fired_scopes = []
+        self.mstore.set_accepted_types(["reysnchronize"])
+
+        def resynchronized(scopes=None):
+            fired_scopes.extend(scopes)
+
+        self.reactor.call_on("resynchronize-clients", resynchronized)
+
+        self.transport.responses.append([{"type": "resynchronize",
+                                          "operation-id": 123,
+                                          "scopes": ["disk", "users"]}])
+        self.exchanger.exchange()
+        self.assertEqual(["disk", "users"], fired_scopes)
+
     def test_no_urgency_when_server_expects_current_message(self):
         """
         When the message the server expects is the same as the first
@@ -878,12 +973,65 @@ class MessageExchangeTest(LandscapeTest):
         expected_log_entry = (
             "Response message with operation-id 234567 was discarded because "
             "the client's secure ID has changed in the meantime")
-        self.assertTrue(expected_log_entry in self.logfile.getvalue())
+        self.assertIn(expected_log_entry, self.logfile.getvalue())
 
         # The MessageContext was removed after utilisation.
         ids_after = self.exchange_store.all_operation_ids()
-        self.assertTrue(len(ids_after) == len(ids_before) - 1)
-        self.assertFalse('234567' in ids_after)
+        self.assertEqual(len(ids_after), len(ids_before) - 1)
+        self.assertNotIn('234567', ids_after)
+
+    def test_error_exchanging_causes_failed_exchange(self):
+        """
+        If a traceback occurs whilst exchanging, the 'exchange-failed'
+        event should be fired.
+        """
+        events = []
+
+        def failed_exchange():
+            events.append(None)
+
+        self.reactor.call_on("exchange-failed", failed_exchange)
+        self.exchanger._transport = RaisingTransport()
+        self.exchanger.exchange()
+        self.assertEqual([None], events)
+
+    def test_error_exchanging_records_failure_in_message_store(self):
+        """
+        If a traceback occurs whilst exchanging, the failure is recorded
+        in the message store.
+        """
+        mock_message_store = self.mocker.proxy(self.mstore)
+        mock_message_store.record_failure(MATCH(lambda x: type(x) is int))
+        self.mocker.result(None)
+        self.mocker.replay()
+
+        exchanger = MessageExchange(
+            self.reactor, mock_message_store, RaisingTransport(),
+            self.identity, self.exchange_store, self.config)
+        exchanger.exchange()
+
+    def test_error_exchanging_marks_exchange_complete(self):
+        """
+        If a traceback occurs whilst exchanging, the exchange is still
+        marked as complete.
+        """
+        events = []
+
+        def exchange_done():
+            events.append(None)
+
+        self.reactor.call_on("exchange-done", exchange_done)
+        self.exchanger._transport = RaisingTransport()
+        self.exchanger.exchange()
+        self.assertEqual([None], events)
+
+    def test_error_exchanging_logs_failure(self):
+        """
+        If a traceback occurs whilst exchanging, the failure is logged.
+        """
+        self.exchanger._transport = RaisingTransport()
+        self.exchanger.exchange()
+        self.assertIn("Message exchange failed.", self.logfile.getvalue())
 
 
 class AcceptedTypesMessageExchangeTest(LandscapeTest):
@@ -988,20 +1136,16 @@ class AcceptedTypesMessageExchangeTest(LandscapeTest):
 class GetAcceptedTypesDiffTest(LandscapeTest):
 
     def test_diff_empty(self):
-        self.assertEqual(get_accepted_types_diff([], []),
-                         "")
+        self.assertEqual(get_accepted_types_diff([], []), "")
 
     def test_diff_add(self):
-        self.assertEqual(get_accepted_types_diff([], ["wubble"]),
-                         "+wubble")
+        self.assertEqual(get_accepted_types_diff([], ["wubble"]), "+wubble")
 
     def test_diff_remove(self):
-        self.assertEqual(get_accepted_types_diff(["wubble"], []),
-                         "-wubble")
+        self.assertEqual(get_accepted_types_diff(["wubble"], []), "-wubble")
 
     def test_diff_no_change(self):
-        self.assertEqual(get_accepted_types_diff(["ooga"], ["ooga"]),
-                         "ooga")
+        self.assertEqual(get_accepted_types_diff(["ooga"], ["ooga"]), "ooga")
 
     def test_diff_complex(self):
         self.assertEqual(get_accepted_types_diff(["foo", "bar"],
