@@ -1,10 +1,12 @@
-from landscape.tests.helpers import LandscapeTest, FakeBrokerServiceHelper
+from landscape.tests.helpers import LandscapeTest
 
 from twisted.internet.defer import fail
 
 from landscape.lib.bpickle import dumps
 from landscape.lib.fetch import fetch
+from landscape.reactor import FakeReactor
 from landscape.broker.ping import PingClient, Pinger
+from landscape.broker.tests.helpers import ExchangeHelper
 
 
 class FakePageGetter(object):
@@ -38,14 +40,16 @@ class FakePageGetter(object):
 
 class PingClientTest(LandscapeTest):
 
-    helpers = [FakeBrokerServiceHelper]
+    def setUp(self):
+        super(PingClientTest, self).setUp()
+        self.reactor = FakeReactor()
 
     def test_default_get_page(self):
         """
         The C{get_page} argument to L{PingClient} should be optional, and
         default to L{twisted.web.client.getPage}.
         """
-        client = PingClient(None, None, None)
+        client = PingClient(self.reactor)
         self.assertEqual(client.get_page, fetch)
 
     def test_ping(self):
@@ -54,12 +58,10 @@ class PingClientTest(LandscapeTest):
         about a particular insecure ID.
         """
         client = FakePageGetter(None)
-        self.broker_service.identity.insecure_id = 10
         url = "http://localhost/ping"
-        pinger = PingClient(self.broker_service.reactor, url,
-                            self.broker_service.identity,
-                            get_page=client.get_page)
-        pinger.ping()
+        insecure_id = 10
+        pinger = PingClient(self.reactor, get_page=client.get_page)
+        pinger.ping(url, insecure_id)
         self.assertEqual(
             client.fetches,
             [(url, True, {"Content-Type": "application/x-www-form-urlencoded"},
@@ -71,11 +73,8 @@ class PingClientTest(LandscapeTest):
         should not happen.
         """
         client = FakePageGetter(None)
-        url = "http://localhost/ping"
-        pinger = PingClient(self.broker_service.reactor,
-                            url, self.broker_service.identity,
-                            get_page=client.get_page)
-        d = pinger.ping()
+        pinger = PingClient(self.reactor, get_page=client.get_page)
+        d = pinger.ping("http://ping/url", None)
         d.addCallback(self.assertEqual, False)
         self.assertEqual(client.fetches, [])
 
@@ -84,26 +83,19 @@ class PingClientTest(LandscapeTest):
         The L{PingClient.ping} fire the Deferred it returns with True if the
         web request indicates that the computer has messages.
         """
-        self.broker_service.identity.insecure_id = 23
         client = FakePageGetter({"messages": True})
-        pinger = PingClient(self.broker_service.reactor,
-                            None, self.broker_service.identity,
-                            get_page=client.get_page)
-        d = pinger.ping()
+        pinger = PingClient(self.reactor, get_page=client.get_page)
+        d = pinger.ping("http://ping/url", 23)
         d.addCallback(self.assertEqual, True)
 
     def test_errback(self):
         """
-        If a L{PingClient} does not have an insecure-id yet, then the ping
-        should not happen.
+        If the HTTP request fails the deferred returned by L{PingClient.ping}
+        fires back with an error.
         """
-        self.broker_service.identity.insecure_id = 23
         client = FakePageGetter(None)
-        url = "http://localhost/ping"
-        pinger = PingClient(self.broker_service.reactor,
-                            url, self.broker_service.identity,
-                            get_page=client.failing_get_page)
-        d = pinger.ping()
+        pinger = PingClient(self.reactor, get_page=client.failing_get_page)
+        d = pinger.ping("http://ping/url", 23)
         failures = []
 
         def errback(failure):
@@ -116,7 +108,7 @@ class PingClientTest(LandscapeTest):
 
 class PingerTest(LandscapeTest):
 
-    helpers = [FakeBrokerServiceHelper]
+    helpers = [ExchangeHelper]
 
     # Tell the Plugin helper to not add a MessageExchange plugin, to interfere
     # with our code which asserts stuff about when *our* plugin fires
@@ -125,34 +117,28 @@ class PingerTest(LandscapeTest):
 
     def setUp(self):
         super(PingerTest, self).setUp()
-
-        class MockConfig(object):
-            ping_url = "http://localhost:8081/whatever"
-            ping_interval = 10
-
-            def write(self):
-                pass
-
-        self.config = MockConfig()
         self.page_getter = FakePageGetter(None)
 
-        def factory(reactor, url, insecure_id):
-            return PingClient(reactor, url, insecure_id,
-                              get_page=self.page_getter.get_page)
-        self.pinger = Pinger(self.broker_service.reactor,
-                             self.broker_service.identity,
-                             self.broker_service.exchanger,
-                             self.config, ping_client_factory=factory)
+        def factory(reactor):
+            return PingClient(reactor, get_page=self.page_getter.get_page)
+
+        self.config.ping_url = "http://localhost:8081/whatever"
+        self.config.ping_interval = 10
+
+        self.pinger = Pinger(self.reactor,
+                             self.identity,
+                             self.exchanger,
+                             self.config,
+                             ping_client_factory=factory)
 
     def test_default_ping_client(self):
         """
         The C{ping_client_factory} argument to L{Pinger} should be optional,
         and default to L{PingClient}.
         """
-        self.config.ping_url = "http://foo.com/"
-        pinger = Pinger(self.broker_service.reactor,
-                        self.broker_service.identity,
-                        self.broker_service.exchanger,
+        pinger = Pinger(self.reactor,
+                        self.identity,
+                        self.exchanger,
                         self.config)
         self.assertEqual(pinger.ping_client_factory, PingClient)
 
@@ -162,10 +148,10 @@ class PingerTest(LandscapeTest):
         messages.
         """
         self.pinger.start()
-        self.broker_service.identity.insecure_id = 23
-        self.broker_service.reactor.advance(9)
+        self.identity.insecure_id = 23
+        self.reactor.advance(9)
         self.assertEqual(len(self.page_getter.fetches), 0)
-        self.broker_service.reactor.advance(1)
+        self.reactor.advance(1)
         self.assertEqual(len(self.page_getter.fetches), 1)
 
     def test_load_insecure_id(self):
@@ -173,9 +159,9 @@ class PingerTest(LandscapeTest):
         If the insecure-id has already been saved when the plugin is
         registered, it should immediately start pinging.
         """
-        self.broker_service.identity.insecure_id = 42
+        self.identity.insecure_id = 42
         self.pinger.start()
-        self.broker_service.reactor.advance(10)
+        self.reactor.advance(10)
         self.assertEqual(len(self.page_getter.fetches), 1)
 
     def test_response(self):
@@ -183,23 +169,23 @@ class PingerTest(LandscapeTest):
         When a ping indicates there are messages, an exchange should occur.
         """
         self.pinger.start()
-        self.broker_service.identity.insecure_id = 42
+        self.identity.insecure_id = 42
         self.page_getter.response = {"messages": True}
 
         # 70 = ping delay + urgent exchange delay
-        self.broker_service.reactor.advance(70)
+        self.reactor.advance(70)
 
-        self.assertEqual(len(self.broker_service.transport.payloads), 1)
+        self.assertEqual(len(self.transport.payloads), 1)
 
     def test_negative_response(self):
         """
         When a ping indicates there are no messages, no exchange should occur.
         """
         self.pinger.start()
-        self.broker_service.identity.insecure_id = 42
+        self.identity.insecure_id = 42
         self.page_getter.response = {"messages": False}
-        self.broker_service.reactor.advance(10)
-        self.assertEqual(len(self.broker_service.transport.payloads), 0)
+        self.reactor.advance(10)
+        self.assertEqual(len(self.transport.payloads), 0)
 
     def test_ping_error(self):
         """
@@ -207,24 +193,25 @@ class PingerTest(LandscapeTest):
         should be logged.
         """
         self.log_helper.ignore_errors(ZeroDivisionError)
-        self.broker_service.identity.insecure_id = 42
+        self.identity.insecure_id = 42
 
         class BadPingClient(object):
             def __init__(self, *args, **kwargs):
-                self.url = args[1]
+                pass
 
-            def ping(self):
+            def ping(self, url, secure_id):
+                self.url = url
                 return fail(ZeroDivisionError("Couldn't fetch page"))
 
         self.config.ping_url = "http://foo.com/"
-        pinger = Pinger(self.broker_service.reactor,
-                        self.broker_service.identity,
-                        self.broker_service.exchanger,
+        pinger = Pinger(self.reactor,
+                        self.identity,
+                        self.exchanger,
                         self.config,
                         ping_client_factory=BadPingClient)
         pinger.start()
 
-        self.broker_service.reactor.advance(30)
+        self.reactor.advance(30)
 
         log = self.logfile.getvalue()
         self.assertTrue("Error contacting ping server at "
@@ -239,36 +226,80 @@ class PingerTest(LandscapeTest):
     def test_set_intervals_handling(self):
         self.pinger.start()
 
-        self.broker_service.reactor.fire("message",
-                                         {"type": "set-intervals", "ping": 73})
+        self.reactor.fire("message", {"type": "set-intervals", "ping": 73})
         self.assertEqual(self.pinger.get_interval(), 73)
 
         # The server may set specific intervals only, not including the ping.
-        self.broker_service.reactor.fire("message", {"type": "set-intervals"})
+        self.reactor.fire("message", {"type": "set-intervals"})
         self.assertEqual(self.pinger.get_interval(), 73)
 
-        self.broker_service.identity.insecure_id = 23
-        self.broker_service.reactor.advance(72)
+        self.identity.insecure_id = 23
+        self.reactor.advance(72)
         self.assertEqual(len(self.page_getter.fetches), 0)
-        self.broker_service.reactor.advance(1)
+        self.reactor.advance(1)
         self.assertEqual(len(self.page_getter.fetches), 1)
 
     def test_get_url(self):
         self.assertEqual(self.pinger.get_url(),
                          "http://localhost:8081/whatever")
 
-    def test_set_url(self):
+    def test_config_url(self):
+        """
+        The L{Pinger} uses the ping URL set in the given configuration.
+        """
+        self.identity.insecure_id = 23
         url = "http://example.com/mysuperping"
-        self.pinger.set_url(url)
+        self.config.ping_url = url
         self.pinger.start()
-        self.broker_service.identity.insecure_id = 23
-        self.broker_service.reactor.advance(10)
+        self.reactor.advance(10)
         self.assertEqual(self.page_getter.fetches[0][0], url)
 
-    def test_set_url_after_start(self):
+    def test_reschedule(self):
+        """
+        Each time a ping is completed the L{Pinger} schedules a new ping using
+        the current ping interval.
+        """
+        self.identity.insecure_id = 23
+        self.pinger.start()
+        self.reactor.advance(10)
+        self.assertEqual(1, len(self.page_getter.fetches))
+        self.reactor.advance(10)
+        self.assertEqual(2, len(self.page_getter.fetches))
+
+    def test_reschedule_with_ping_interval_change(self):
+        """
+        If the ping interval changes, new pings will be scheduled accordingly.
+        """
+        self.identity.insecure_id = 23
+        self.pinger.start()
+        self.reactor.advance(5)
+        # Simulate interval changing in the meantime
+        self.config.ping_interval = 20
+        self.reactor.advance(5)
+        self.assertEqual(1, len(self.page_getter.fetches))
+        # The new interval is 20, so after only 10 seconds nothing happens
+        self.reactor.advance(10)
+        self.assertEqual(1, len(self.page_getter.fetches))
+        # After another 10 seconds we reach the 20 seconds interval and the
+        # ping is triggered
+        self.reactor.advance(10)
+        self.assertEqual(2, len(self.page_getter.fetches))
+
+    def test_change_url_after_start(self):
+        """
+        If the C{ping_url} set in the configuration is changed after the
+        pinger has started, the target HTTP url will adjust accordingly.
+        """
         url = "http://example.com/mysuperping"
         self.pinger.start()
-        self.pinger.set_url(url)
-        self.broker_service.identity.insecure_id = 23
-        self.broker_service.reactor.advance(10)
+        self.config.ping_url = url
+        self.identity.insecure_id = 23
+        self.reactor.advance(10)
         self.assertEqual(self.page_getter.fetches[0][0], url)
+
+    def test_ping_doesnt_ping_if_stopped(self):
+        """If the L{Pinger} is stopped, no pings are performed."""
+        self.pinger.start()
+        self.pinger.stop()
+        self.reactor.advance(10)
+        self.assertEqual([], self.page_getter.fetches)
