@@ -1,3 +1,4 @@
+import json
 import os
 import logging
 import pycurl
@@ -69,6 +70,9 @@ class IdentityTest(LandscapeTest):
     def test_client_tags(self):
         self.check_config_property("tags")
 
+    def test_access_group(self):
+        self.check_config_property("access_group")
+
 
 class RegistrationHandlerTestBase(LandscapeTest):
 
@@ -161,14 +165,9 @@ class RegistrationHandlerTest(RegistrationHandlerTestBase):
         self.config.computer_title = "Computer Title"
         self.config.account_name = "account_name"
         self.reactor.fire("pre-exchange")
-        self.assertMessages(self.mstore.get_pending_messages(),
-                            [{"type": "register",
-                              "computer_title": "Computer Title",
-                              "account_name": "account_name",
-                              "registration_password": None,
-                              "hostname": "ooga.local",
-                              "tags": None,
-                              "vm-info": get_vm_info()}])
+        messages = self.mstore.get_pending_messages()
+        self.assertEqual(1, len(messages))
+        self.assertEqual("register", messages[0]["type"])
         self.assertEqual(self.logfile.getvalue().strip(),
                          "INFO: Queueing message to register with account "
                          "'account_name' without a password.")
@@ -177,7 +176,7 @@ class RegistrationHandlerTest(RegistrationHandlerTestBase):
         """
         When a computer_title and account_name are available, no
         secure_id is set, and an exchange is about to happen,
-        queue a registration message.
+        queue a registration message with VM information.
         """
         get_vm_info_mock = self.mocker.replace(get_vm_info)
         get_vm_info_mock()
@@ -187,18 +186,29 @@ class RegistrationHandlerTest(RegistrationHandlerTestBase):
         self.config.computer_title = "Computer Title"
         self.config.account_name = "account_name"
         self.reactor.fire("pre-exchange")
-        self.assertMessages(self.mstore.get_pending_messages(),
-                            [{"type": "register",
-                              "computer_title": "Computer Title",
-                              "account_name": "account_name",
-                              "registration_password": None,
-                              "hostname": "ooga.local",
-                              "tags": None,
-                              "vm-info": u"vmware"}])
+        messages = self.mstore.get_pending_messages()
+        self.assertEqual("vmware", messages[0]["vm-info"])
         self.assertEqual(self.logfile.getvalue().strip(),
                          "INFO: Queueing message to register with account "
                          "'account_name' without a password.")
 
+    def test_queue_message_on_exchange_with_lxc_container(self):
+        """
+        If the client is running in an LXC container, the information is
+        included in the registration message.
+        """
+        get_container_info_mock = self.mocker.replace(
+            "landscape.lib.vm_info.get_container_info")
+        get_container_info_mock()
+        self.mocker.result("lxc")
+        self.mocker.replay()
+        self.mstore.set_accepted_types(["register"])
+        self.config.computer_title = "Computer Title"
+        self.config.account_name = "account_name"
+        self.reactor.fire("pre-exchange")
+        messages = self.mstore.get_pending_messages()
+        self.assertEqual("lxc", messages[0]["container-info"])
+
     def test_queue_message_on_exchange_with_password(self):
         """If a registration password is available, we pass it on!"""
         self.mstore.set_accepted_types(["register"])
@@ -206,14 +216,9 @@ class RegistrationHandlerTest(RegistrationHandlerTestBase):
         self.config.account_name = "account_name"
         self.config.registration_key = "SEKRET"
         self.reactor.fire("pre-exchange")
-        self.assertMessages(self.mstore.get_pending_messages(),
-                            [{"type": "register",
-                              "computer_title": "Computer Title",
-                              "account_name": "account_name",
-                              "registration_password": "SEKRET",
-                              "hostname": "ooga.local",
-                              "tags": None,
-                              "vm-info": get_vm_info()}])
+        messages = self.mstore.get_pending_messages()
+        password = messages[0]["registration_password"]
+        self.assertEqual("SEKRET", password)
         self.assertEqual(self.logfile.getvalue().strip(),
                          "INFO: Queueing message to register with account "
                          "'account_name' with a password.")
@@ -229,14 +234,8 @@ class RegistrationHandlerTest(RegistrationHandlerTestBase):
         self.config.registration_key = "SEKRET"
         self.config.tags = u"computer,tag"
         self.reactor.fire("pre-exchange")
-        self.assertMessages(self.mstore.get_pending_messages(),
-                            [{"type": "register",
-                              "computer_title": "Computer Title",
-                              "account_name": "account_name",
-                              "registration_password": "SEKRET",
-                              "hostname": "ooga.local",
-                              "tags": u"computer,tag",
-                              "vm-info": get_vm_info()}])
+        messages = self.mstore.get_pending_messages()
+        self.assertEqual("computer,tag", messages[0]["tags"])
         self.assertEqual(self.logfile.getvalue().strip(),
                          "INFO: Queueing message to register with account "
                          "'account_name' and tags computer,tag "
@@ -255,14 +254,8 @@ class RegistrationHandlerTest(RegistrationHandlerTestBase):
         self.config.registration_key = "SEKRET"
         self.config.tags = u"<script>alert()</script>"
         self.reactor.fire("pre-exchange")
-        self.assertMessages(self.mstore.get_pending_messages(),
-                            [{"type": "register",
-                              "computer_title": "Computer Title",
-                              "account_name": "account_name",
-                              "registration_password": "SEKRET",
-                              "hostname": "ooga.local",
-                              "tags": None,
-                              "vm-info": get_vm_info()}])
+        messages = self.mstore.get_pending_messages()
+        self.assertIs(None, messages[0]["tags"])
         self.assertEqual(self.logfile.getvalue().strip(),
                          "ERROR: Invalid tags provided for cloud "
                          "registration.\n    "
@@ -280,20 +273,56 @@ class RegistrationHandlerTest(RegistrationHandlerTestBase):
         self.config.registration_key = "SEKRET"
         self.config.tags = u"prova\N{LATIN SMALL LETTER J WITH CIRCUMFLEX}o"
         self.reactor.fire("pre-exchange")
-        self.assertMessages(
-            self.mstore.get_pending_messages(),
-            [{"type": "register",
-              "computer_title": "Computer Title",
-              "account_name": "account_name",
-              "registration_password": "SEKRET",
-              "hostname": "ooga.local",
-              "tags": u"prova\N{LATIN SMALL LETTER J WITH CIRCUMFLEX}o",
-              "vm-info": get_vm_info()}])
+        messages = self.mstore.get_pending_messages()
+        expected = u"prova\N{LATIN SMALL LETTER J WITH CIRCUMFLEX}o"
+        self.assertEqual(expected, messages[0]["tags"])
+
         self.assertEqual(self.logfile.getvalue().strip(),
                          "INFO: Queueing message to register with account "
                          "'account_name' and tags prova\xc4\xb5o "
                          "with a password.")
 
+    def test_queue_message_on_exchange_with_access_group(self):
+        """
+        If the admin has defined an access_group for this computer, we send
+        it to the server.
+        """
+        self.mstore.set_accepted_types(["register"])
+        self.config.account_name = "account_name"
+        self.config.access_group = u"dinosaurs"
+        self.config.tags = u"server,london"
+        self.reactor.fire("pre-exchange")
+        messages = self.mstore.get_pending_messages()
+        self.assertEqual("dinosaurs", messages[0]["access_group"])
+        self.assertEqual(self.logfile.getvalue().strip(),
+                         "INFO: Queueing message to register with account "
+                         "'account_name' in access group 'dinosaurs' and "
+                         "tags server,london without a password.")
+
+    def test_queue_message_on_exchange_with_empty_access_group(self):
+        """
+        If the access_group is "", then the outgoing message does not define
+        an "access_group" key.
+        """
+        self.mstore.set_accepted_types(["register"])
+        self.config.access_group = u""
+        self.reactor.fire("pre-exchange")
+        messages = self.mstore.get_pending_messages()
+        # Make sure the key does not appear in the outgoing message.
+        self.assertNotIn("access_group", messages[0])
+
+    def test_queue_message_on_exchange_with_none_access_group(self):
+        """
+        If the access_group is None, then the outgoing message does not define
+        an "access_group" key.
+        """
+        self.mstore.set_accepted_types(["register"])
+        self.config.access_group = None
+        self.reactor.fire("pre-exchange")
+        messages = self.mstore.get_pending_messages()
+        # Make sure the key does not appear in the outgoing message.
+        self.assertNotIn("access_group", messages[0])
+
     def test_queueing_registration_message_resets_message_store(self):
         """
         When a registration message is queued, the store is reset
@@ -398,11 +427,14 @@ class RegistrationHandlerTest(RegistrationHandlerTestBase):
         self.assertEqual(self.logfile.getvalue(), "")
 
     def test_resynchronize_fired_when_registration_done(self):
-
+        """
+        When we call C{register} this should trigger a "resynchronize-clients"
+        event with global scope.
+        """
         results = []
 
-        def append():
-            results.append(True)
+        def append(scopes=None):
+            results.append(scopes)
 
         self.reactor.call_on("resynchronize-clients", append)
 
@@ -412,7 +444,7 @@ class RegistrationHandlerTest(RegistrationHandlerTestBase):
         self.exchanger.handle_message(
             {"type": "set-id", "id": "abc", "insecure-id": "def"})
 
-        self.assertEqual(results, [True])
+        self.assertEqual(results, [None])
 
     def test_register_deferred_called_on_failed(self):
         # We don't want informational messages.
@@ -471,14 +503,32 @@ class RegistrationHandlerTest(RegistrationHandlerTestBase):
         self.config.account_name = "account_name"
         self.config.registration_key = "SEKRET"
         self.reactor.fire("pre-exchange")
-        self.assertMessages(self.mstore.get_pending_messages(),
-                            [{"type": "register",
-                              "computer_title": "Computer Title",
-                              "account_name": "account_name",
-                              "registration_password": "SEKRET",
-                              "hostname": socket.getfqdn(),
-                              "vm-info": get_vm_info(),
-                              "tags": None}])
+        messages = self.mstore.get_pending_messages()
+        self.assertEqual(socket.getfqdn(), messages[0]["hostname"])
+
+
+class JujuRegistrationHandlerTest(RegistrationHandlerTestBase):
+
+    juju_contents = json.dumps({"environment-uuid": "DEAD-BEEF",
+                                "unit-name": "service/0",
+                                "api-addresses": "10.0.3.1:17070",
+                                "private-address": "127.0.0.1"})
+
+    def test_juju_information_added_when_present(self):
+        """
+        When Juju information is found in $data_dir/juju-info.json,
+        key parts of it are sent in the registration message.
+        """
+        self.mstore.set_accepted_types(["register"])
+        self.config.account_name = "account_name"
+        self.reactor.fire("run")
+        self.reactor.fire("pre-exchange")
+
+        messages = self.mstore.get_pending_messages()
+        expected = {"environment-uuid": "DEAD-BEEF",
+                    "api-addresses": ["10.0.3.1:17070"],
+                    "unit-name": "service/0"}
+        self.assertEqual(expected, messages[0]["juju-info"])
 
 
 class CloudRegistrationHandlerTest(RegistrationHandlerTestBase):
@@ -539,7 +589,8 @@ class CloudRegistrationHandlerTest(RegistrationHandlerTestBase):
             self.query_results[api_base + url_suffix] = value
 
     def prepare_cloud_registration(self, account_name=None,
-                                   registration_key=None, tags=None):
+                                   registration_key=None, tags=None,
+                                   access_group=None):
         # Set things up so that the client thinks it should register
         self.mstore.set_accepted_types(list(self.mstore.get_accepted_types())
                                        + ["register-cloud-vm"])
@@ -547,6 +598,7 @@ class CloudRegistrationHandlerTest(RegistrationHandlerTestBase):
         self.config.registration_key = registration_key
         self.config.computer_title = None
         self.config.tags = tags
+        self.config.access_group = access_group
         self.identity.secure_id = None
         self.assertTrue(self.handler.should_register())
 
@@ -571,14 +623,12 @@ class CloudRegistrationHandlerTest(RegistrationHandlerTestBase):
                        local_ipv4=u"10.0.0.1",
                        public_ipv4=u"10.0.0.2",
                        tags=None)
-
-        # The get_vm_info() needs to be deffered to the else.  If vm-info is
-        # specified in kwargs, get_vm_info() will typically be mocked.
+        # The get_vm_info() needs to be deferred to the else.  If vm-info is
+        # not specified in kwargs, get_vm_info() will typically be mocked.
         if "vm_info" in kwargs:
             message["vm-info"] = kwargs.pop("vm_info")
         else:
             message["vm-info"] = get_vm_info()
-
         message.update(kwargs)
         return message
 
@@ -625,6 +675,24 @@ class CloudRegistrationHandlerTest(RegistrationHandlerTestBase):
             [self.get_expected_cloud_message(tags=u"server,london",
                                              vm_info="xen")])
 
+    def test_cloud_registration_with_access_group(self):
+        """
+        If the access_group field is presnet in the configuration, the
+        access_group field is present in the outgoing message for a VM
+        registration, and a notice appears in the logs.
+        """
+        self.prepare_query_results()
+        self.prepare_cloud_registration(access_group=u"dinosaurs",
+                                        tags=u"server,london")
+
+        self.reactor.fire("run")
+        self.exchanger.exchange()
+        self.assertEqual(len(self.transport.payloads), 1)
+        self.assertMessages(
+            self.transport.payloads[0]["messages"],
+            [self.get_expected_cloud_message(
+                access_group=u"dinosaurs", tags=u"server,london")])
+
     def test_cloud_registration_with_otp(self):
         """
         If the OTP is present in the configuration, it's used to trigger the
@@ -902,14 +970,8 @@ class CloudRegistrationHandlerTest(RegistrationHandlerTestBase):
         self.assertIn("HTTPCodeError: Server returned HTTP code 404",
                       self.logfile.getvalue())
         self.assertEqual(len(self.transport.payloads), 1)
-        self.assertMessages(self.transport.payloads[0]["messages"],
-                            [{"type": "register",
-                              "computer_title": u"whatever",
-                              "account_name": u"onward",
-                              "registration_password": u"password",
-                              "hostname": socket.getfqdn(),
-                              "vm-info": get_vm_info(),
-                              "tags": None}])
+        messages = self.transport.payloads[0]["messages"]
+        self.assertEqual("register", messages[0]["type"])
 
     def test_should_register_in_cloud(self):
         """
@@ -1154,7 +1216,5 @@ class ProvisioningRegistrationTest(RegistrationHandlerTestBase):
         self.config.provisioning_otp = ""
         self.reactor.fire("pre-exchange")
 
-        self.assertMessages([],
-                            self.mstore.get_pending_messages())
-        self.assertEqual(u"",
-                         self.logfile.getvalue().strip())
+        self.assertMessages([], self.mstore.get_pending_messages())
+        self.assertEqual(u"", self.logfile.getvalue().strip())
