@@ -1,5 +1,7 @@
 from twisted.internet.defer import succeed, fail
 
+from configobj import ConfigObj
+
 from landscape.manager.manager import FAILED
 from landscape.tests.helpers import LandscapeTest, DEFAULT_ACCEPTED_TYPES
 from landscape.broker.tests.helpers import (
@@ -30,14 +32,40 @@ class BrokerServerTest(LandscapeTest):
         """
         self.assertTrue(self.broker.ping())
 
+    def test_get_session_id(self):
+        """
+        The L{BrokerServer.get_session_id} method gets the same
+        session ID from the L{MessageStore} until it is dropped.
+        """
+        session_id1 = self.broker.get_session_id()
+        session_id2 = self.broker.get_session_id()
+        self.assertEqual(session_id1, session_id2)
+        self.mstore.drop_session_ids()
+        session_id3 = self.broker.get_session_id()
+        self.assertNotEqual(session_id1, session_id3)
+
+    def test_get_session_id_with_scope(self):
+        """
+        The L{BrokerServer.get_session_id} method gets the same session ID from
+        the L{MessageStore} for the same scope, but a new session ID for a new
+        scope.
+        """
+        disk_session_id1 = self.broker.get_session_id(scope="disk")
+        disk_session_id2 = self.broker.get_session_id(scope="disk")
+        users_session_id = self.broker.get_session_id(scope="users")
+        self.assertEqual(disk_session_id1, disk_session_id2)
+        self.assertNotEqual(disk_session_id1, users_session_id)
+
     def test_send_message(self):
+
         """
         The L{BrokerServer.send_message} method forwards a message to the
         broker's exchanger.
         """
         message = {"type": "test"}
         self.mstore.set_accepted_types(["test"])
-        self.broker.send_message(message)
+        session_id = self.broker.get_session_id()
+        self.broker.send_message(message, session_id)
         self.assertMessages(self.mstore.get_pending_messages(), [message])
         self.assertFalse(self.exchanger.is_urgent())
 
@@ -48,10 +76,34 @@ class BrokerServerTest(LandscapeTest):
         """
         message = {"type": "test"}
         self.mstore.set_accepted_types(["test"])
-        self.broker.send_message(message, True)
+        session_id = self.broker.get_session_id()
+        self.broker.send_message(message, session_id, urgent=True)
         self.assertMessages(self.mstore.get_pending_messages(), [message])
         self.assertTrue(self.exchanger.is_urgent())
 
+    def test_send_message_wont_send_with_invalid_session_id(self):
+        """
+        The L{BrokerServer.send_message} call will silently drop messages
+        that have invalid session ids as they must have been generated
+        prior to the last resync request - this guards against out of
+        context data being sent to the server.
+        """
+        message = {"type": "test"}
+        self.mstore.set_accepted_types(["test"])
+        self.broker.send_message(message, "Not Valid")
+        self.assertMessages(self.mstore.get_pending_messages(), [])
+
+    def test_send_message_with_none_as_session_id_raises(self):
+        """
+        We should never call C{send_message} without first obtaining a session
+        id.  Attempts to do so should raise to alert the developer to their
+        mistake.
+        """
+        message = {"type": "test"}
+        self.mstore.set_accepted_types(["test"])
+        self.assertRaises(
+            RuntimeError, self.broker.send_message, message, None)
+
     def test_is_pending(self):
         """
         The L{BrokerServer.is_pending} method indicates if a message with
@@ -60,7 +112,8 @@ class BrokerServerTest(LandscapeTest):
         self.assertFalse(self.broker.is_message_pending(123))
         message = {"type": "test"}
         self.mstore.set_accepted_types(["test"])
-        message_id = self.broker.send_message(message)
+        session_id = self.broker.get_session_id()
+        message_id = self.broker.send_message(message, session_id)
         self.assertTrue(self.broker.is_message_pending(message_id))
 
     def test_register_client(self):
@@ -125,7 +178,9 @@ class BrokerServerTest(LandscapeTest):
         The L{BrokerServer.reload_configuration} method forces the config
         file associated with the broker server to be reloaded.
         """
-        open(self.config_filename, "a").write("computer_title = New Title")
+        config_obj = ConfigObj(self.config_filename)
+        config_obj["client"]["computer_title"] = "New Title"
+        config_obj.write()
         result = self.broker.reload_configuration()
         result.addCallback(lambda x: self.assertEqual(
             self.config.computer_title, "New Title"))
@@ -332,10 +387,11 @@ class EventTest(LandscapeTest):
         event to all connected clients.
         """
         callback = self.mocker.mock()
-        self.expect(callback()).result("foo")
+        self.expect(callback(["foo"])).result("foo")
         self.mocker.replay()
         self.client_reactor.call_on("resynchronize", callback)
-        return self.assertSuccess(self.broker.resynchronize(), [["foo"]])
+        return self.assertSuccess(self.broker.resynchronize(["foo"]),
+                                  [["foo"]])
 
     def test_impending_exchange(self):
         """
