@@ -4,8 +4,7 @@ import os
 
 from landscape.lib.persist import Persist
 from landscape.broker.store import MessageStore
-from landscape.schema import (
-    InvalidError, Message, Int, String, UnicodeOrString)
+from landscape.schema import InvalidError, Message, Int, Bytes, Unicode
 
 from landscape.tests.helpers import LandscapeTest
 from landscape.tests.mocker import ANY
@@ -16,20 +15,19 @@ class MessageStoreTest(LandscapeTest):
 
     def setUp(self):
         super(MessageStoreTest, self).setUp()
-        self.time = 0
         self.temp_dir = tempfile.mkdtemp()
         self.persist_filename = tempfile.mktemp()
         self.store = self.create_store()
 
     def create_store(self):
         persist = Persist(filename=self.persist_filename)
-        store = MessageStore(persist, self.temp_dir, 20,
-                             get_time=self.get_time)
-        store.set_accepted_types(["empty", "data"])
+        store = MessageStore(persist, self.temp_dir, 20)
+        store.set_accepted_types(["empty", "data", "resynchronize"])
         store.add_schema(Message("empty", {}))
         store.add_schema(Message("empty2", {}))
-        store.add_schema(Message("data", {"data": String()}))
-        store.add_schema(Message("unaccepted", {"data": String()}))
+        store.add_schema(Message("data", {"data": Bytes()}))
+        store.add_schema(Message("unaccepted", {"data": Bytes()}))
+        store.add_schema(Message("resynchronize", {}))
         return store
 
     def tearDown(self):
@@ -38,9 +36,6 @@ class MessageStoreTest(LandscapeTest):
         if os.path.isfile(self.persist_filename):
             os.unlink(self.persist_filename)
 
-    def get_time(self):
-        return self.time
-
     def test_get_set_sequence(self):
         self.assertEqual(self.store.get_sequence(), 0)
         self.store.set_sequence(3)
@@ -103,6 +98,7 @@ class MessageStoreTest(LandscapeTest):
 
     def test_delete_no_messages(self):
         self.store.delete_old_messages()
+        self.assertEqual(0, self.store.count_pending_messages())
 
     def test_delete_old_messages_does_not_delete_held(self):
         """
@@ -237,9 +233,8 @@ class MessageStoreTest(LandscapeTest):
         filename = os.path.join(self.temp_dir, "0", "0")
         self.assertTrue(os.path.isfile(filename))
 
-        file = open(filename, "w")
-        file.write("bpickle will break reading this")
-        file.close()
+        with open(filename, "w") as fh:
+            fh.write("bpickle will break reading this")
 
         self.assertEqual(self.store.get_pending_messages(), [])
 
@@ -251,8 +246,7 @@ class MessageStoreTest(LandscapeTest):
         # store call an event handler when it encounters a broken
         # message and hooking on that for this assertion instead of
         # relying on this fragile check.
-        self.assertTrue("invalid literal for int()" in self.logfile.getvalue(),
-                        self.logfile.getvalue())
+        self.assertIn("invalid literal for int()", self.logfile.getvalue())
 
         self.logfile.seek(0)
         self.logfile.truncate()
@@ -261,8 +255,7 @@ class MessageStoreTest(LandscapeTest):
         self.store.set_accepted_types([])
         self.store.set_accepted_types(["empty", "empty2"])
 
-        self.assertTrue("invalid literal for int()" in self.logfile.getvalue(),
-                        self.logfile.getvalue())
+        self.assertIn("invalid literal for int()", self.logfile.getvalue())
 
     def test_wb_delete_messages_with_broken(self):
         self.log_helper.ignore_errors(ValueError)
@@ -272,9 +265,8 @@ class MessageStoreTest(LandscapeTest):
         filename = os.path.join(self.temp_dir, "0", "0")
         self.assertTrue(os.path.isfile(filename))
 
-        file = open(filename, "w")
-        file.write("bpickle will break reading this")
-        file.close()
+        with open(filename, "w") as fh:
+            fh.write("bpickle will break reading this")
 
         messages = self.store.get_pending_messages()
 
@@ -286,7 +278,7 @@ class MessageStoreTest(LandscapeTest):
         messages = self.store.get_pending_messages()
         self.store.delete_old_messages()
         self.assertEqual(messages, [])
-        self.assertTrue("ValueError" in self.logfile.getvalue())
+        self.assertIn("ValueError", self.logfile.getvalue())
 
     def test_atomic_message_writing(self):
         """
@@ -355,8 +347,7 @@ class MessageStoreTest(LandscapeTest):
         The message that eventually gets sent should be the result of
         the coercion.
         """
-        self.store.add_schema(
-            Message("data", {"data": UnicodeOrString("utf-8")}))
+        self.store.add_schema(Message("data", {"data": Unicode()}))
         self.store.add({"type": "data",
                         "data": u"\N{HIRAGANA LETTER A}".encode("utf-8"),
                         "api": "whatever"})
@@ -403,9 +394,8 @@ class MessageStoreTest(LandscapeTest):
         filename = os.path.join(self.temp_dir, "0", "0")
         self.assertTrue(os.path.isfile(filename))
 
-        file = open(filename, "w")
-        file.write("bpickle will break reading this")
-        file.close()
+        with open(filename, "w") as fh:
+            fh.write("bpickle will break reading this")
 
         # And hold the second one.
         self.store.add({"type": "data", "data": "A thing"})
@@ -426,7 +416,6 @@ class MessageStoreTest(LandscapeTest):
         self.assertFalse(self.store.is_pending(id))
 
     def test_is_pending_with_held_message(self):
-
         self.store.set_accepted_types(["empty"])
         id = self.store.add({"type": "data", "data": "A thing"})
 
@@ -447,10 +436,150 @@ class MessageStoreTest(LandscapeTest):
         filename = os.path.join(self.temp_dir, "0", "0")
         self.assertTrue(os.path.isfile(filename))
 
-        file = open(filename, "w")
-        file.write("bpickle will break reading this")
-        file.close()
+        with open(filename, "w") as fh:
+            fh.write("bpickle will break reading this")
 
         self.assertEqual(self.store.get_pending_messages(), [])
 
         self.assertFalse(self.store.is_pending(id))
+
+    def test_get_session_id_returns_the_same_id_for_the_same_scope(self):
+        """We get the same id returned from get_session_id when we used the
+        same scope.
+        """
+        global_session_id1 = self.store.get_session_id()
+        global_session_id2 = self.store.get_session_id()
+        self.assertEqual(global_session_id1, global_session_id2)
+
+    def test_get_session_id_unique_for_each_scope(self):
+        """We get a unique session id for differing scopes.
+        """
+        session_id1 = self.store.get_session_id()
+        session_id2 = self.store.get_session_id(scope="other")
+        self.assertNotEqual(session_id1, session_id2)
+
+    def test_get_session_id_assigns_global_scope_when_none_is_provided(self):
+        """Test that get_session_id puts session ids in global scope by
+        default.
+        """
+        session_id = self.store.get_session_id()
+        persisted_ids = self.store._persist.get('session-ids')
+        scope = persisted_ids[session_id]
+        self.assertIs(None, scope)
+
+    def test_get_session_id_with_scope(self):
+        """Test that we can generate a session id within a limited scope."""
+        session_id = self.store.get_session_id(scope="hwinfo")
+        persisted_ids = self.store._persist.get('session-ids')
+        scope = persisted_ids[session_id]
+        self.assertEqual("hwinfo", scope)
+
+    def test_persisted_session_ids_are_valid(self):
+        """
+        Test that generated session ids are persisted in the message store
+        and can be validated with C{is_valid_session_id}.
+        """
+        session_id = self.store.get_session_id()
+        self.assertTrue(self.store.is_valid_session_id(session_id))
+
+    def test_unknown_session_ids_are_not_valid(self):
+        """
+        If the provided session id is not in the persisted list of session
+        ids then it can not be validated with C{is_valid_session_id}.
+        """
+        session_id = "I've got a lovely bunch of coconuts"
+        self.assertFalse(self.store.is_valid_session_id(session_id))
+
+    def test_drop_session_ids(self):
+        """
+        Session ids can be dropped on demand.
+        """
+        session_id = self.store.get_session_id()
+        self.store.drop_session_ids()
+        self.assertFalse(self.store.is_valid_session_id(session_id))
+
+    def test_drop_session_ids_drops_all_scopes_with_no_scopes_parameter(self):
+        """When C{drop_session_ids} is called with no scopes then all
+        session_ids are dropped.
+        """
+        session_id1 = self.store.get_session_id()
+        session_id2 = self.store.get_session_id(scope="hwinfo")
+        self.store.drop_session_ids()
+        self.assertFalse(self.store.is_valid_session_id(session_id1))
+        self.assertFalse(self.store.is_valid_session_id(session_id2))
+
+    def test_drop_session_ids_with_scope_drops_only_that_scope(self):
+        """Calling C{drop_session_ids} with a scope only deletes session_ids
+        within that scope."""
+        global_session_id = self.store.get_session_id()
+        hwinfo_session_id = self.store.get_session_id(scope="hwinfo")
+        package_session_id = self.store.get_session_id(scope="package")
+        self.store.drop_session_ids(scopes=["hwinfo"])
+        self.assertTrue(self.store.is_valid_session_id(global_session_id))
+        self.assertFalse(self.store.is_valid_session_id(hwinfo_session_id))
+        self.assertTrue(self.store.is_valid_session_id(package_session_id))
+
+    def test_drop_multiple_scopes(self):
+        """
+        If we pass multiple scopes into C{drop_session_ids} then those scopes
+        are all dropped but no other are.
+        """
+        global_session_id = self.store.get_session_id()
+        disk_session_id = self.store.get_session_id(scope="disk")
+        hwinfo_session_id = self.store.get_session_id(scope="hwinfo")
+        package_session_id = self.store.get_session_id(scope="package")
+        self.store.drop_session_ids(scopes=["hwinfo", "disk"])
+        self.assertTrue(self.store.is_valid_session_id(global_session_id))
+        self.assertFalse(self.store.is_valid_session_id(disk_session_id))
+        self.assertFalse(self.store.is_valid_session_id(hwinfo_session_id))
+        self.assertTrue(self.store.is_valid_session_id(package_session_id))
+
+    def test_record_failure_sets_first_failure_time(self):
+        """first-failure-time recorded when calling record_failure()."""
+        self.store.record_failure(123)
+        self.assertEqual(
+            123, self.store._persist.get("first-failure-time"))
+
+    def test_messages_rejected_if_failure_older_than_one_week(self):
+        """Messages stop accumulating after one week of not being sent."""
+        self.store.record_failure(0)
+        self.store.record_failure(7 * 24 * 60 * 60)
+        self.assertIsNot(None, self.store.add({"type": "empty"}))
+        self.store.record_failure((7 * 24 * 60 * 60) + 1)
+        self.assertIs(None, self.store.add({"type": "empty"}))
+        self.assertIn("WARNING: Unable to succesfully communicate with "
+                      "Landscape server for more than a week. Waiting for "
+                      "resync.",
+                      self.logfile.getvalue())
+        # Resync message and the first one we added right on the week boundary
+        self.assertEqual(2, len(self.store.get_pending_messages()))
+
+    def test_no_new_messages_after_discarded_following_one_week(self):
+        """
+        After one week of not being sent, no new messages are queued.
+        """
+        self.store.record_failure(0)
+        self.store.add({"type": "empty"})
+        self.store.record_failure((7 * 24 * 60 * 60) + 1)
+        self.store.add({"type": "empty"})
+        self.assertIs(None, self.store.add({"type": "empty"}))
+        self.assertIn("DEBUG: Dropped message, awaiting resync.",
+                      self.logfile.getvalue())
+
+    def test_after_clearing_blackhole_messages_are_accepted_again(self):
+        """After a successful exchange, messages are accepted again."""
+        self.store.record_failure(0)
+        self.store.add({"type": "empty"})
+        self.store.record_failure((7 * 24 * 60 * 60) + 1)
+        self.store.add({"type": "empty"})
+        self.assertIs(None, self.store.add({"type": "empty"}))
+        self.store.record_success((7 * 24 * 60 * 60) + 2)
+        self.assertIsNot(None, self.store.add({"type": "empty"}))
+
+    def test_resync_requested_after_one_week_of_failures(self):
+        """After a week of failures, a resync is requested."""
+        self.store.record_failure(0)
+        self.store.add({"type": "empty"})
+        self.store.record_failure((7 * 24 * 60 * 60) + 1)
+        [empty, message] = self.store.get_pending_messages()
+        self.assertEqual("resynchronize", message["type"])
