@@ -11,7 +11,7 @@ import sys
 import os
 import getpass
 import pwd
-from ConfigParser import ConfigParser, Error as ConfigParserError
+
 from StringIO import StringIO
 
 from landscape.lib.tag import is_valid_tag
@@ -78,7 +78,7 @@ class LandscapeSetupConfiguration(BrokerConfiguration):
         line options.
         """
         if self.import_from:
-            parser = ConfigParser()
+            parser = None
 
             try:
                 if "://" in self.import_from:
@@ -88,23 +88,26 @@ class LandscapeSetupConfiguration(BrokerConfiguration):
                     if self.https_proxy:
                         os.environ["https_proxy"] = self.https_proxy
                     content = self.fetch_import_url(self.import_from)
-                    parser.readfp(StringIO(content))
+                    parser = self._get_config_object(
+                        alternative_config=StringIO(content))
                 elif not os.path.isfile(self.import_from):
                     raise ImportOptionError("File %s doesn't exist." %
                                             self.import_from)
                 else:
-                    succesfully_read_files = parser.read(self.import_from)
-                    if self.import_from not in succesfully_read_files:
+                    try:
+                        parser = self._get_config_object(
+                            alternative_config=self.import_from)
+                    except:
                         raise ImportOptionError(
                             "Couldn't read configuration from %s." %
                             self.import_from)
-            except ConfigParserError, error:
+            except Exception, error:
                 raise ImportOptionError(str(error))
 
             # But real command line options have precedence.
             options = None
-            if parser.has_section(self.config_section):
-                options = dict(parser.items(self.config_section))
+            if parser and self.config_section in parser:
+                options = parser[self.config_section]
             if not options:
                 raise ImportOptionError("Nothing to import at %s." %
                                         self.import_from)
@@ -371,6 +374,16 @@ class LandscapeSetupScript(object):
                 included_plugins.remove("ScriptExecution")
         self.config.include_manager_plugins = ", ".join(included_plugins)
 
+    def query_access_group(self):
+        """Query access group from the user."""
+        self.show_help("You may provide an access group for this computer "
+                       "e.g. webservers.")
+
+        options = self.config.get_command_line_options()
+        if "access_group" in options:
+            return  # an access group is already provided, don't ask for one
+        self.prompt("access_group", "Access group", False)
+
     def _get_invalid_tags(self, tagnames):
         """
         Splits a string on , and checks the validity of each tag, returns any
@@ -426,6 +439,7 @@ class LandscapeSetupScript(object):
         self.query_registration_key()
         self.query_proxies()
         self.query_script_plugin()
+        self.query_access_group()
         self.query_tags()
 
 
