@@ -1,11 +1,12 @@
 import os
 import sys
 
+from configobj import ConfigObj, ConfigObjError
+
 from logging import (getLevelName, getLogger,
                      FileHandler, StreamHandler, Formatter)
 
 from optparse import OptionParser, SUPPRESS_HELP
-from ConfigParser import ConfigParser, NoSectionError
 
 from landscape import VERSION
 from landscape.lib.persist import Persist
@@ -30,6 +31,20 @@ def init_logging(configuration, program_name):
         handler.setFormatter(Formatter(format))
 
 
+class ConfigSpecOptionParser(OptionParser):
+
+    _config_spec_definitions = {}
+
+    def __init__(self, unsaved_options=None):
+        OptionParser.__init__(self, unsaved_options)
+
+    def add_option(self, *args, **kwargs):
+        option = OptionParser.add_option(self, *args, **kwargs)
+        print dir(option)
+        print option.get_opt_string()
+        return option
+
+
 class BaseConfiguration(object):
     """Base class for configuration implementations.
 
@@ -141,20 +156,27 @@ class BaseConfiguration(object):
         """
         self.load_command_line(args)
 
-        # Parse configuration file, if found.
         if self.config:
-            if os.path.isfile(self.config):
-                if not os.access(self.config, os.R_OK):
-                    sys.exit(
-                        "error: config file %s can't be read" % self.config)
-                self.load_configuration_file(self.config)
-            elif not accept_nonexistent_config:
-                sys.exit("error: file not found: %s" % self.config)
+            config_filenames = [self.config]
         else:
-            for potential_config_file in self.default_config_filenames:
-                if os.access(potential_config_file, os.R_OK):
-                    self.load_configuration_file(potential_config_file)
-                    break
+            config_filenames = self.default_config_filenames
+        # Parse configuration file, if found.
+        for config_filename in config_filenames:
+            if (os.path.isfile(config_filename)
+                and os.access(config_filename, os.R_OK)):
+
+                self.load_configuration_file(config_filename)
+                break
+
+        else:
+            if not accept_nonexistent_config:
+                if len(config_filenames) == 1:
+                    message = (
+                        "error: config file %s can't be read" %
+                        config_filenames[0])
+                else:
+                    message = "error: no config file could be read"
+                sys.exit(message)
 
         self._load_external_options()
 
@@ -181,14 +203,39 @@ class BaseConfiguration(object):
         then the old data will take precedence.
         """
         self._config_filename = filename
-        config_parser = ConfigParser()
-        config_parser.read(filename)
+        config_obj = self._get_config_object()
         try:
-            self._config_file_options = dict(
-                config_parser.items(self.config_section))
-        except NoSectionError:
+            self._config_file_options = config_obj[self.config_section]
+        except KeyError:
             pass
 
+    def _get_config_object(self, alternative_config=None):
+        """Create a L{ConfigObj} consistent with our preferences.
+
+        @param config_source: Optional readable source to read from instead of
+            the default configuration file.
+        """
+        config_source = alternative_config or self.get_config_filename()
+        # Setting list_values to False prevents ConfigObj from being "smart"
+        # about lists (it now treats them as strings). See bug #1228301 for
+        # more context.
+        # Setting raise_errors to False causes ConfigObj to batch all parsing
+        # errors into one ConfigObjError raised at the end of the parse instead
+        # of raising the first one and then exiting.  This also allows us to
+        # recover the good config values in the error handler below.
+        # Setting write_empty_values to True prevents configObj writes
+        # from writing "" as an empty value, which get_plugins interprets as
+        # '""' which search for a plugin named "".  See bug #1241821.
+        try:
+            config_obj = ConfigObj(config_source, list_values=False,
+                                   raise_errors=False, write_empty_values=True)
+        except ConfigObjError, e:
+            logger = getLogger()
+            logger.warn(str(e))
+            # Good configuration values are recovered here
+            config_obj = e.config
+        return config_obj
+
     def write(self):
         """Write back configuration to the configuration file.
 
@@ -207,24 +254,30 @@ class BaseConfiguration(object):
         # The filename we'll write to
         filename = self.get_config_filename()
 
-        config_parser = ConfigParser()
         # Make sure we read the old values from the config file so that we
         # don't remove *unrelated* values.
-        config_parser.read(filename)
-        if not config_parser.has_section(self.config_section):
-            config_parser.add_section(self.config_section)
+        config_obj = self._get_config_object()
+        if not self.config_section in config_obj:
+            config_obj[self.config_section] = {}
         all_options = self._config_file_options.copy()
         all_options.update(self._command_line_options)
         all_options.update(self._set_options)
+        section = config_obj[self.config_section]
         for name, value in all_options.items():
             if name != "config" and name not in self.unsaved_options:
-                if value == self._command_line_defaults.get(name):
-                    config_parser.remove_option(self.config_section, name)
+                if (value == self._command_line_defaults.get(name) and
+                    name not in self._config_file_options and
+                    name not in self._command_line_options):
+                    # We don't want to write this value to the config file
+                    # as it is default value and as not present in the
+                    # config file
+                    if name in config_obj[self.config_section]:
+                        del config_obj[self.config_section][name]
                 else:
-                    config_parser.set(self.config_section, name, value)
-        config_file = open(filename, "w")
-        config_parser.write(config_file)
-        config_file.close()
+                    section[name] = value
+        config_obj[self.config_section] = section
+        config_obj.filename = filename
+        config_obj.write()
 
     def make_parser(self):
         """Parser factory for supported options
@@ -373,6 +426,11 @@ class Configuration(BaseConfiguration):
         """
         return os.path.join(self.data_path, "annotations.d")
 
+    @property
+    def juju_filename(self):
+        """Get the path to the Juju JSON file."""
+        return os.path.join(self.data_path, "juju-info.json")
+
 
 def get_versioned_persist(service):
     """Get a L{Persist} database with upgrade rules applied.
