@@ -5,6 +5,8 @@ import array
 import fcntl
 import socket
 import struct
+import errno
+import logging
 
 __all__ = ["get_active_device_info", "get_network_traffic", "is_64"]
 
@@ -16,6 +18,8 @@ SIOCGIFBRDADDR = 0x8919
 SIOCGIFADDR = 0x8915
 SIOCGIFHWADDR = 0x8927
 
+SIOCETHTOOL = 0x8946  # As defined in include/uapi/linux/sockios.h
+ETHTOOL_GSET = 0x00000001  # Get status command.
 
 # struct definition from header /usr/include/net/if.h
 # the struct size varies according to the platform arch size
@@ -37,7 +41,7 @@ def is_64():
     return struct.calcsize("l") == 8
 
 
-# initialize the struct size as per the machine's archictecture
+# initialize the struct size as per the machine's architecture
 IF_STRUCT_SIZE = is_64() and IF_STRUCT_SIZE_64 or IF_STRUCT_SIZE_32
 
 
@@ -48,7 +52,7 @@ def get_active_interfaces(sock):
     """
     max_interfaces = 128
 
-    # Setup an an array to hold our response, and initialized to null strings.
+    # Setup an array to hold our response, and initialized to null strings.
     interfaces = array.array("B", "\0" * max_interfaces * IF_STRUCT_SIZE)
     buffer_size = interfaces.buffer_info()[0]
     packed_bytes = struct.pack(
@@ -137,23 +141,30 @@ def get_active_device_info(skipped_interfaces=("lo",),
     interface present on a machine.
     """
     results = []
-    sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM, socket.IPPROTO_IP)
-    for interface in get_active_interfaces(sock):
-        if interface in skipped_interfaces:
-            continue
-        if skip_vlan and "." in interface:
-            continue
-        if skip_alias and ":" in interface:
-            continue
-        interface_info = {"interface": interface}
-        interface_info["ip_address"] = get_ip_address(sock, interface)
-        interface_info["mac_address"] = get_mac_address(sock, interface)
-        interface_info["broadcast_address"] = get_broadcast_address(sock,
-                                                                    interface)
-        interface_info["netmask"] = get_netmask(sock, interface)
-        interface_info["flags"] = get_flags(sock, interface)
-        results.append(interface_info)
-    del sock
+    try:
+        sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM,
+                             socket.IPPROTO_IP)
+        for interface in get_active_interfaces(sock):
+            if interface in skipped_interfaces:
+                continue
+            if skip_vlan and "." in interface:
+                continue
+            if skip_alias and ":" in interface:
+                continue
+            interface_info = {"interface": interface}
+            interface_info["ip_address"] = get_ip_address(sock, interface)
+            interface_info["mac_address"] = get_mac_address(sock, interface)
+            interface_info["broadcast_address"] = get_broadcast_address(
+                sock, interface)
+            interface_info["netmask"] = get_netmask(sock, interface)
+            interface_info["flags"] = get_flags(sock, interface)
+            speed, duplex = get_network_interface_speed(sock, interface)
+            interface_info["speed"] = speed
+            interface_info["duplex"] = duplex
+            results.append(interface_info)
+    finally:
+        del sock
+
     return results
 
 
@@ -203,6 +214,44 @@ def get_fqdn():
     return fqdn
 
 
-if __name__ == "__main__":
-    import pprint
-    pprint.pprint(get_active_device_info())
+def get_network_interface_speed(sock, interface_name):
+    """
+    Return the ethernet device's advertised link speed.
+
+    The return value can be one of:
+        * 10, 100, 1000, 2500, 10000: The interface speed in Mbps
+        * -1: The interface does not support querying for max speed, such as
+          virtio devices for instance.
+        * 0: The cable is not connected to the interface. We cannot measure
+          interface speed, but could if it was plugged in.
+    """
+    cmd_struct = struct.pack('I39s', ETHTOOL_GSET, '\x00' * 39)
+    status_cmd = array.array('B', cmd_struct)
+    packed = struct.pack('16sP', interface_name, status_cmd.buffer_info()[0])
+
+    speed = -1
+    try:
+        fcntl.ioctl(sock, SIOCETHTOOL, packed)  # Status ioctl() call
+        res = status_cmd.tostring()
+        speed, duplex = struct.unpack('12xHB28x', res)
+    except IOError as e:
+        if e.errno == errno.EPERM:
+            logging.warn("Could not determine network interface speed, "
+                         "operation not permitted.")
+        elif e.errno != errno.EOPNOTSUPP:
+            raise e
+        speed = -1
+        duplex = False
+
+    # Drivers apparently report speed as 65535 when the link is not available
+    # (cable unplugged for example).
+    if speed == 65535:
+        speed = 0
+
+    # The drivers report "duplex" to be 255 when the information is not
+    # available. We'll just assume it's False in that case.
+    if duplex == 255:
+        duplex = False
+    duplex = bool(duplex)
+
+    return speed, duplex
