@@ -2,34 +2,13 @@ import os
 
 from landscape.tests.helpers import LandscapeTest
 
-from landscape.lib.vm_info import get_vm_info
+from landscape.lib.vm_info import get_vm_info, get_container_info
 
 
-class VMInfoTest(LandscapeTest):
-
-    sample_cpuinfo = """
-processor	: 0
-vendor_id	: GenuineIntel
-cpu family	: 6
-model		: 2
-model name	: QEMU Virtual CPU version 0.14.0
-stepping	: 3
-cpu MHz		: 2653.112
-cache size	: 4096 KB
-fpu		: yes
-fpu_exception	: yes
-cpuid level	: 4
-wp		: yes
-flags		: {flags}
-bogomips	: 5306.22
-clflush size	: 64
-cache_alignment	: 64
-address sizes	: 40 bits physical, 48 bits virtual
-power management:
-"""
+class GetVMInfoTest(LandscapeTest):
 
     def setUp(self):
-        super(VMInfoTest, self).setUp()
+        super(GetVMInfoTest, self).setUp()
         self.root_path = self.makeDir()
         self.proc_path = self.makeDir(
             path=os.path.join(self.root_path, "proc"))
@@ -37,11 +16,11 @@ power management:
         self.proc_sys_path = self.makeDir(
             path=os.path.join(self.proc_path, "sys"))
 
-    def make_cpuinfo(self, flags=""):
-        """Build a sample /proc/cpuinfo with specified processor flags."""
-        cpuinfo_path = os.path.join(self.root_path, "proc/cpuinfo")
-        self.makeFile(
-            path=cpuinfo_path, content=self.sample_cpuinfo.format(flags=flags))
+    def make_sys_vendor(self, content):
+        """Create /sys/class/dmi/id/sys_vendor with the specified content."""
+        dmi_path = os.path.join(self.root_path, "sys/class/dmi/id")
+        self.makeDir(path=dmi_path)
+        self.makeFile(dirname=dmi_path, basename="sys_vendor", content=content)
 
     def test_get_vm_info_empty_when_no_virtualization_is_found(self):
         """
@@ -88,19 +67,13 @@ power management:
 
         self.assertEqual("xen", get_vm_info(root_path=self.root_path))
 
-    def test_get_vm_info_is_empty_when_no_hypervisor_in_proc_cpuinfo(self):
+    def test_get_vm_info_is_empty_without_xen_devices(self):
         """
-        L{get_vm_info} returns an empty string when the "hypervisor" flag is
-        not found in found in /proc/cpuinfo.
+        L{get_vm_info} returns an empty string if the /sys/bus/xen/devices
+        directory exists but doesn't contain any file.
         """
-        self.make_cpuinfo(flags="fpu vme")
-
-        # The content of sys_vendor is not checked if the "hypervisor" flag is
-        # not present.
-        dmi_path = os.path.join(self.root_path, "sys/class/dmi/id")
-        self.makeDir(path=dmi_path)
-        self.makeFile(
-            path=os.path.join(dmi_path, "sys_vendor"), content="Bochs")
+        devices_xen_path = os.path.join(self.sys_path, "bus/xen/devices")
+        self.makeDir(path=devices_xen_path)
 
         self.assertEqual("", get_vm_info(root_path=self.root_path))
 
@@ -109,13 +82,7 @@ power management:
         L{get_vm_info} should return "kvm" when we detect the sys_vendor is
         Bochs.
         """
-        self.make_cpuinfo(flags="fpu hypervisor vme")
-
-        dmi_path = os.path.join(self.root_path, "sys/class/dmi/id")
-        self.makeDir(path=dmi_path)
-        self.makeFile(
-            path=os.path.join(dmi_path, "sys_vendor"), content="Bochs")
-
+        self.make_sys_vendor("Bochs")
         self.assertEqual("kvm", get_vm_info(root_path=self.root_path))
 
     def test_get_vm_info_with_openstack_sys_vendor(self):
@@ -123,14 +90,7 @@ power management:
         L{get_vm_info} should return "kvm" when we detect the sys_vendor is
         Openstack.
         """
-        self.make_cpuinfo(flags="fpu hypervisor vme")
-
-        dmi_path = os.path.join(self.root_path, "sys/class/dmi/id")
-        self.makeDir(path=dmi_path)
-        self.makeFile(
-            path=os.path.join(dmi_path, "sys_vendor"),
-            content="OpenStack Foundation")
-
+        self.make_sys_vendor("OpenStack Foundation")
         self.assertEqual("kvm", get_vm_info(root_path=self.root_path))
 
     def test_get_vm_info_with_vmware_sys_vendor(self):
@@ -138,51 +98,58 @@ power management:
         L{get_vm_info} should return "vmware" when we detect the sys_vendor is
         VMware Inc.
         """
-        self.make_cpuinfo(flags="fpu hypervisor vme")
-
-        dmi_path = os.path.join(self.root_path, "sys/class/dmi/id")
-        self.makeDir(path=dmi_path)
-        self.makeFile(
-            path=os.path.join(dmi_path, "sys_vendor"), content="VMware, Inc.")
-
+        self.make_sys_vendor("VMware, Inc.")
         self.assertEqual("vmware", get_vm_info(root_path=self.root_path))
 
-    def test_get_vm_info_is_empty_without_xen_devices(self):
+    def test_get_vm_info_with_virtualbox_sys_vendor(self):
         """
-        L{get_vm_info} returns an empty string if the /sys/bus/xen/devices
-        directory exists and but doesn't contain any file.
+        L{get_vm_info} should return "virtualbox" when we detect the sys_vendor
+        is innotek GmbH.
         """
-        self.make_cpuinfo(flags="fpu hypervisor vme")
-
-        devices_xen_path = os.path.join(self.sys_path, "bus/xen/devices")
-        self.makeDir(path=devices_xen_path)
-
-        self.assertEqual("", get_vm_info(root_path=self.root_path))
+        self.make_sys_vendor("innotek GmbH")
+        self.assertEqual("virtualbox", get_vm_info(root_path=self.root_path))
 
     def test_get_vm_info_with_microsoft_sys_vendor(self):
         """
         L{get_vm_info} returns "hyperv" if the sys_vendor is Microsoft.
         """
-        self.make_cpuinfo(flags="fpu hypervisor vme")
-
-        dmi_path = os.path.join(self.root_path, "sys/class/dmi/id")
-        self.makeDir(path=dmi_path)
-        self.makeFile(
-            path=os.path.join(dmi_path, "sys_vendor"),
-            content="Microsoft Corporation")
+        self.make_sys_vendor("Microsoft Corporation")
         self.assertEqual("hyperv", get_vm_info(root_path=self.root_path))
 
+    def test_get_vm_info_with_kvm_on_other_architecture(self):
+        """
+        L{get_vm_info} returns 'kvm', if no sys_vendor is available but the
+        model in /proc/cpuinfo contains 'emulated by qemu'.
+        """
+        cpuinfo_path = os.path.join(self.proc_path, "cpuinfo")
+        cpuinfo = (
+            "platform	: Some Machine\n"
+            "model	: Some CPU (emulated by qemu)\n"
+            "machine	: Some Machine (emulated by qemu)\n")
+        self.makeFile(path=cpuinfo_path, content=cpuinfo)
+        self.assertEqual("kvm", get_vm_info(root_path=self.root_path))
+
     def test_get_vm_info_with_other_vendor(self):
         """
         L{get_vm_info} should return an empty string when the sys_vendor is
         unknown.
         """
-        self.make_cpuinfo(flags="fpu hypervisor vme")
-
-        dmi_path = os.path.join(self.root_path, "sys/class/dmi/id")
-        self.makeDir(path=dmi_path)
-        self.makeFile(
-            path=os.path.join(dmi_path, "sys_vendor"),
-            content="Some other vendor")
-
+        self.make_sys_vendor("Some other vendor")
         self.assertEqual("", get_vm_info(root_path=self.root_path))
+
+
+class GetContainerInfoTest(LandscapeTest):
+
+    def test_no_container(self):
+        """If not running in a container, an empty string is returned."""
+        self.assertEqual("", get_container_info(path="/does/not/exist"))
+
+    def test_in_container(self):
+        """If running in a container, the container type is returned."""
+        path = self.makeFile(content="lxc")
+        self.assertEqual("lxc", get_container_info(path=path))
+
+    def test_strip_newline(self):
+        """The container type doesn't contain newlines."""
+        path = self.makeFile(content="lxc\n")
+        self.assertEqual("lxc", get_container_info(path=path))
