@@ -352,8 +352,8 @@ class ActiveProcessInfoTest(LandscapeTest):
 
     def test_resynchronize_event(self):
         """
-        When a C{resynchronize} event occurs we should clear the information
-        held in memory by the activeprocess monitor.
+        When a C{resynchronize} event occurs, with 'process' scope, we should
+        clear the information held in memory by the activeprocess monitor.
         """
         self.builder.create_data(1, self.builder.RUNNING, uid=0, gid=0,
                                  started_after_boot=1030, process_name="init")
@@ -406,6 +406,64 @@ class ActiveProcessInfoTest(LandscapeTest):
         # No new messages should be pending
         self.assertMessages(messages, expected_messages)
 
+        process_scope = ["process"]
+        self.reactor.fire("resynchronize", process_scope)
+        plugin.exchange()
+        messages = self.mstore.get_pending_messages()
+        # The resynchronisation should cause the same messages to be generated
+        # again.
+        expected_messages.extend(expected_messages)
+        self.assertMessages(messages, expected_messages)
+
+    def test_resynchronize_event_resets_session_id(self):
+        """
+        When a C{resynchronize} event occurs a new session id is acquired so
+        that future messages can be sent.
+        """
+        plugin = ActiveProcessInfo(proc_dir=self.sample_dir, uptime=100,
+                                   jiffies=10, boot_time=0)
+        self.monitor.add(plugin)
+        session_id = plugin._session_id
+        plugin.client.broker.message_store.drop_session_ids()
+        self.reactor.fire("resynchronize")
+        plugin.exchange()
+        self.assertNotEqual(session_id, plugin._session_id)
+
+    def test_resynchronize_event_with_global_scope(self):
+        """
+        When a C{resynchronize} event occurs the L{_reset} method should be
+        called on L{ActiveProcessInfo}.
+        """
+        self.builder.create_data(672, self.builder.TRACING_STOP,
+                                 uid=1000, gid=1000, started_after_boot=1120,
+                                 process_name="blarpy")
+
+        plugin = ActiveProcessInfo(proc_dir=self.sample_dir, uptime=100,
+                                   jiffies=10, boot_time=0)
+        self.monitor.add(plugin)
+
+        plugin.exchange()
+        messages = self.mstore.get_pending_messages()
+
+        expected_messages = [{"add-processes": [
+                               {"gid": 1000,
+                                "name": u"blarpy",
+                                "pid": 672,
+                                "start-time": 112,
+                                "state": "t",
+                                "uid": 1000,
+                                "vm-size": 11676,
+                                "percent-cpu": 0.0}],
+                              "kill-all-processes": True,
+                              "type": "active-process-info"}]
+
+        self.assertMessages(messages, expected_messages)
+
+        plugin.exchange()
+        messages = self.mstore.get_pending_messages()
+        # No new messages should be pending
+        self.assertMessages(messages, expected_messages)
+
         self.reactor.fire("resynchronize")
         plugin.exchange()
         messages = self.mstore.get_pending_messages()
@@ -414,6 +472,49 @@ class ActiveProcessInfoTest(LandscapeTest):
         expected_messages.extend(expected_messages)
         self.assertMessages(messages, expected_messages)
 
+    def test_do_not_resynchronize_with_other_scope(self):
+        """
+        When a C{resynchronize} event occurs, with an irrelevant scope, we
+        should do nothing.
+        """
+        self.builder.create_data(672, self.builder.TRACING_STOP,
+                                 uid=1000, gid=1000, started_after_boot=1120,
+                                 process_name="blarpy")
+
+        plugin = ActiveProcessInfo(proc_dir=self.sample_dir, uptime=100,
+                                   jiffies=10, boot_time=0)
+        self.monitor.add(plugin)
+
+        plugin.exchange()
+        messages = self.mstore.get_pending_messages()
+
+        expected_messages = [{"add-processes": [
+                               {"gid": 1000,
+                                "name": u"blarpy",
+                                "pid": 672,
+                                "start-time": 112,
+                                "state": "t",
+                                "uid": 1000,
+                                "vm-size": 11676,
+                                "percent-cpu": 0.0}],
+                              "kill-all-processes": True,
+                              "type": "active-process-info"}]
+
+        self.assertMessages(messages, expected_messages)
+
+        plugin.exchange()
+        messages = self.mstore.get_pending_messages()
+        # No new messages should be pending
+        self.assertMessages(messages, expected_messages)
+
+        disk_scope = ["disk"]
+        self.reactor.fire("resynchronize", disk_scope)
+        plugin.exchange()
+        messages = self.mstore.get_pending_messages()
+        # The resynchronisation should not have fired, so we won't see any
+        # additional messages here.
+        self.assertMessages(messages, expected_messages)
+
     def test_do_not_persist_changes_when_send_message_fails(self):
         """
         When the plugin is run it persists data that it uses on
@@ -434,7 +535,7 @@ class ActiveProcessInfoTest(LandscapeTest):
         self.monitor.add(plugin)
 
         broker_mock = self.mocker.replace(self.monitor.broker)
-        broker_mock.send_message(ANY, urgent=ANY)
+        broker_mock.send_message(ANY, ANY, urgent=ANY)
         self.mocker.result(fail(MyException()))
         self.mocker.replay()
 
