@@ -134,7 +134,7 @@ class LoadAveragePluginTest(LandscapeTest):
         self.reactor.advance(self.monitor.step_size * 1)
 
         remote_broker_mock = self.mocker.replace(self.remote)
-        remote_broker_mock.send_message(ANY, urgent=True)
+        remote_broker_mock.send_message(ANY, ANY, urgent=True)
         self.mocker.replay()
 
         self.reactor.fire(("message-type-acceptance-changed", "load-average"),
