@@ -422,7 +422,7 @@ addr=ennui 0 0
 
         plugin.run()
         plugin.exchange()
-        self.reactor.fire("resynchronize")
+        self.reactor.fire("resynchronize", scopes=["disk"])
         plugin.run()
         plugin.exchange()
         messages = self.mstore.get_pending_messages()
@@ -553,7 +553,7 @@ addr=ennui 0 0
         self.reactor.advance(plugin.run_interval)
 
         remote_broker_mock = self.mocker.replace(self.remote)
-        remote_broker_mock.send_message(ANY, urgent=True)
+        remote_broker_mock.send_message(ANY, ANY, urgent=True)
         self.mocker.result(succeed(None))
         self.mocker.count(2)
         self.mocker.replay()
