@@ -32,7 +32,7 @@ class ProcessorInfoTest(LandscapeTest):
         self.monitor.add(plugin)
 
         remote_broker_mock = self.mocker.replace(self.remote)
-        remote_broker_mock.send_message(ANY, urgent=True)
+        remote_broker_mock.send_message(ANY, ANY, urgent=True)
         self.mocker.replay()
 
         self.reactor.fire(
@@ -53,7 +53,7 @@ class ResynchTest(LandscapeTest):
         plugin = ProcessorInfo()
         self.monitor.add(plugin)
         plugin.run()
-        self.reactor.fire("resynchronize")
+        self.reactor.fire("resynchronize", scopes=["cpu"])
         plugin.run()
         messages = self.mstore.get_pending_messages()
         self.assertEqual(len(messages), 2)
