@@ -50,6 +50,7 @@ class AptPackageChangerTest(LandscapeTest):
             landscape_reactor=self.landscape_reactor,
             reboot_required_filename=reboot_required_filename)
         self.changer.update_notifier_stamp = "/Not/Existing"
+        self.changer.get_session_id()
         service = self.broker_service
         service.message_store.set_accepted_types(["change-packages-result",
                                                   "operation-result"])
@@ -1487,3 +1488,14 @@ class AptPackageChangerTest(LandscapeTest):
         self.broker_service.reactor.advance(100)
         self.landscape_reactor.advance(10)
         return result.addCallback(got_result)
+
+    def test_run_gets_session_id(self):
+        """
+        Invoking L{PackageChanger.run} results in the session ID being fetched.
+        """
+        def assert_session_id(ignored):
+            self.assertTrue(self.changer._session_id is not None)
+
+        self.changer._session_id = None
+        result = self.changer.run()
+        return result.addCallback(assert_session_id)
