@@ -1,6 +1,5 @@
 import sys
 import os
-import unittest
 import time
 import apt_pkg
 
@@ -28,7 +27,7 @@ from landscape.tests.mocker import ANY
 SAMPLE_LSB_RELEASE = "DISTRIB_CODENAME=codename\n"
 
 
-class PackageReporterConfigurationTest(unittest.TestCase):
+class PackageReporterConfigurationTest(LandscapeTest):
 
     def test_force_apt_update_option(self):
         """
@@ -36,6 +35,7 @@ class PackageReporterConfigurationTest(unittest.TestCase):
         command line option.
         """
         config = PackageReporterConfiguration()
+        config.default_config_filenames = (self.makeFile(""), )
         self.assertFalse(config.force_apt_update)
         config.load(["--force-apt-update"])
         self.assertTrue(config.force_apt_update)
@@ -53,6 +53,7 @@ class PackageReporterAptTest(LandscapeTest):
         self.config = PackageReporterConfiguration()
         self.reporter = PackageReporter(
             self.store, self.facade, self.remote, self.config)
+        self.reporter.get_session_id()
         # Assume update-notifier-common stamp file is not present by
         # default.
         self.reporter.update_notifier_stamp = "/Not/Existing"
@@ -230,7 +231,7 @@ class PackageReporterAptTest(LandscapeTest):
         deferred.errback(Boom())
 
         remote_mock = self.mocker.patch(self.reporter._broker)
-        remote_mock.send_message(ANY, True)
+        remote_mock.send_message(ANY, ANY, True)
         self.mocker.result(deferred)
         self.mocker.replay()
 
@@ -732,7 +733,7 @@ class PackageReporterAptTest(LandscapeTest):
         deferred.errback(Boom())
 
         remote_mock = self.mocker.patch(self.reporter._broker)
-        remote_mock.send_message(ANY, True)
+        remote_mock.send_message(ANY, ANY, True)
         self.mocker.result(deferred)
         self.mocker.replay()
 
@@ -1662,6 +1663,7 @@ class GlobalPackageReporterAptTest(LandscapeTest):
         deferred = Deferred()
 
         def do_test():
+            self.reporter.get_session_id()
             result = self.reporter.run_apt_update()
 
             def callback(ignore):
@@ -1709,8 +1711,9 @@ class FakePackageReporterTest(LandscapeTest):
         self.global_store.save_message(message)
 
         def check(ignore):
+            messages = message_store.get_pending_messages()
             self.assertMessages(
-                message_store.get_pending_messages(), [message])
+                messages, [message])
             stored = list(self.store._db.execute(
                 "SELECT id FROM message").fetchall())
             self.assertEqual(1, len(stored))
