@@ -63,8 +63,8 @@ class Float(object):
         return value
 
 
-class String(object):
-    """Something that must be a C{str}."""
+class Bytes(object):
+    """A binary string."""
     def coerce(self, value):
         if not isinstance(value, str):
             raise InvalidError("%r isn't a str" % (value,))
@@ -72,22 +72,14 @@ class String(object):
 
 
 class Unicode(object):
-    """Something that must be a C{unicode}."""
-    def coerce(self, value):
-        if not isinstance(value, unicode):
-            raise InvalidError("%r isn't a unicode" % (value,))
-        return value
-
-
-class UnicodeOrString(object):
-    """Something that must be a C{unicode} or {str}.
+    """Something that must be a C{unicode}.
 
     If the value is a C{str}, it will automatically be decoded.
 
     @param encoding: The encoding to automatically decode C{str}s with.
     """
 
-    def __init__(self, encoding):
+    def __init__(self, encoding="utf-8"):
         self.encoding = encoding
 
     def coerce(self, value):
@@ -217,7 +209,7 @@ class Message(KeyDict):
     def __init__(self, type, schema, optional=None):
         self.type = type
         schema["timestamp"] = Float()
-        schema["api"] = Any(String(), Constant(None))
+        schema["api"] = Any(Bytes(), Constant(None))
         schema["type"] = Constant(type)
         if optional is not None:
             optional.extend(["timestamp", "api"])
