@@ -1,12 +1,13 @@
 """Deployment code for the sysinfo tool."""
 import os
+import sys
 from logging import getLogger, Formatter
 from logging.handlers import RotatingFileHandler
 
 from twisted.python.reflect import namedClass
 from twisted.internet.defer import Deferred, maybeDeferred
 
-from landscape.deployment import Configuration
+from landscape.deployment import BaseConfiguration
 from landscape.sysinfo.sysinfo import SysInfoPluginRegistry, format_sysinfo
 
 
@@ -14,7 +15,7 @@ ALL_PLUGINS = ["Load", "Disk", "Memory", "Temperature", "Processes",
                "LoggedInUsers", "LandscapeLink", "Network"]
 
 
-class SysInfoConfiguration(Configuration):
+class SysInfoConfiguration(BaseConfiguration):
     """Specialized configuration for the Landscape sysinfo tool."""
 
     default_config_filenames = ("/etc/landscape/client.conf",)
@@ -91,7 +92,10 @@ def run(args, reactor=None, sysinfo=None):
     """
     @param reactor: The reactor to (optionally) run the sysinfo plugins in.
     """
-    setup_logging()
+    try:
+        setup_logging()
+    except IOError, e:
+        sys.exit("Unable to setup logging. %s" % e)
 
     if sysinfo is None:
         sysinfo = SysInfoPluginRegistry()
