@@ -44,10 +44,10 @@ class MemoryTest(LandscapeTest):
         self.sysinfo.add(self.memory)
 
     def test_run_returns_succeeded_deferred(self):
-        self.assertDeferredSucceeded(self.memory.run())
+        self.assertIs(None, self.successResultOf(self.memory.run()))
 
     def test_run_adds_header(self):
         self.memory.run()
         self.assertEqual(self.sysinfo.get_headers(),
-                         [("Memory usage", "34%"),
+                         [("Memory usage", "27%"),
                           ("Swap usage", "39%")])
