@@ -99,7 +99,7 @@ class LandscapeTest(MessageTestCase, MockerTestCase,
 
     def setUp(self):
         self._old_config_filenames = BaseConfiguration.default_config_filenames
-        BaseConfiguration.default_config_filenames = []
+        BaseConfiguration.default_config_filenames = [self.makeFile("")]
         MockerTestCase.setUp(self)
         TestCase.setUp(self)
         return HelperTestCase.setUp(self)
@@ -395,7 +395,6 @@ class MonitorHelper(FakeBrokerServiceHelper):
     """
 
     def set_up(self, test_case):
-
         super(MonitorHelper, self).set_up(test_case)
         persist = Persist()
         persist_filename = test_case.makePersistFile()
@@ -639,3 +638,16 @@ CapEff: 0000000000000000
         """Remove sample data for the process that matches C{process_id}."""
         process_dir = os.path.join(self._sample_dir, str(process_id))
         shutil.rmtree(process_dir)
+
+
+class FakePersist(object):
+    """
+    Incompletely fake a C{landscape.lib.Persist} to simplify higher level tests
+    that result in an attempt to clear down persisted data.
+    """
+
+    def __init__(self):
+        self.called = False
+
+    def remove(self, key):
+        self.called = True
