@@ -562,8 +562,7 @@ class LandscapeSetupScriptTest(LandscapeTest):
         self.mocker.result(u"root")
         self.mocker.replay()
         self.script.query_script_plugin()
-        self.assertEqual(self.config.script_users,
-                         "root")
+        self.assertEqual(self.config.script_users, "root")
 
     def test_tags_not_defined_on_command_line(self):
         """
@@ -607,12 +606,39 @@ class LandscapeSetupScriptTest(LandscapeTest):
         self.assertEqual(self.config.tags, u"server,london")
 
     def test_invalid_tags_defined_on_command_line_raises_error(self):
+        """
+        Invalid tags on the command line raises a ConfigurationError.
+        """
         raw_input_mock = self.mocker.replace(raw_input, passthrough=False)
         self.expect(raw_input_mock(ANY)).count(0)
         self.mocker.replay()
         self.config.load_command_line(["--tags", u"<script>alert();</script>"])
         self.assertRaises(ConfigurationError, self.script.query_tags)
 
+    def test_access_group_not_defined_on_command_line(self):
+        """
+        If an access group is not provided, the user should be prompted for it.
+        """
+        self.mocker.order()
+        script_mock = self.mocker.patch(self.script)
+        script_mock.show_help("You may provide an access group for this "
+                              "computer e.g. webservers.")
+        script_mock.prompt("access_group", "Access group", False)
+        self.mocker.replay()
+        self.script.query_access_group()
+
+    def test_access_group_defined_on_command_line(self):
+        """
+        An access group defined on the command line can be verified by the
+        user.
+        """
+        raw_input_mock = self.mocker.replace(raw_input, passthrough=False)
+        self.expect(raw_input_mock(ANY)).count(0)
+        self.mocker.replay()
+        self.config.load_command_line(["--access-group", u"webservers"])
+        self.script.query_access_group()
+        self.assertEqual(self.config.access_group, u"webservers")
+
     def test_show_header(self):
         help_snippet = "This script will"
         script_mock = self.mocker.patch(self.script)
@@ -629,6 +655,7 @@ class LandscapeSetupScriptTest(LandscapeTest):
         script_mock.query_registration_key()
         script_mock.query_proxies()
         script_mock.query_script_plugin()
+        script_mock.query_access_group()
         script_mock.query_tags()
         self.mocker.replay()
 
@@ -691,6 +718,7 @@ class ConfigurationFunctionsTest(LandscapeConfigurationTest):
                                  "https_proxy = https://old.proxy\n"
                                  "url = http://url\n"
                                  "include_manager_plugins = ScriptExecution\n"
+                                 "access_group = webservers\n"
                                  "tags = london, server")
 
         raw_input = self.mocker.replace("__builtin__.raw_input",
@@ -706,6 +734,8 @@ class ConfigurationFunctionsTest(LandscapeConfigurationTest):
         expect(raw_input(C("[http://old.proxy]"))).result("http://new.proxy")
         expect(raw_input(C("[https://old.proxy]"))).result("https://new.proxy")
         expect(raw_input(C("Enable script execution? [Y/n]"))).result("n")
+        expect(raw_input(C("Access group [webservers]: "))).result(
+            u"databases")
         expect(raw_input(C("Tags [london, server]: "))).result(
             u"glasgow, laptop")
 
@@ -730,6 +760,7 @@ class ConfigurationFunctionsTest(LandscapeConfigurationTest):
         self.assertEqual(config.http_proxy, "http://new.proxy")
         self.assertEqual(config.https_proxy, "https://new.proxy")
         self.assertEqual(config.include_manager_plugins, "")
+        self.assertEqual(config.access_group, u"databases")
         self.assertEqual(config.tags, u"glasgow, laptop")
 
     def test_silent_setup(self):
@@ -749,6 +780,7 @@ class ConfigurationFunctionsTest(LandscapeConfigurationTest):
 computer_title = rex
 data_path = %s
 account_name = account
+url = https://landscape.canonical.com/message-system
 """ % config.data_path)
 
     def test_silent_setup_no_register(self):
@@ -765,6 +797,7 @@ account_name = account
         self.assertConfigEqual(self.get_content(config), """\
 [client]
 data_path = %s
+url = https://landscape.canonical.com/message-system
 """ % config.data_path)
 
     def test_silent_setup_no_register_with_default_preseed_params(self):
@@ -792,7 +825,8 @@ data_path = %s
                 "--provisioning-otp", ""]
         config = self.get_config(args)
         setup(config)
-        self.assertConfigEqual(self.get_content(config),
+        self.assertConfigEqual(
+            self.get_content(config),
             "[client]\n"
             "http_proxy = \n"
             "tags = \n"
@@ -801,6 +835,13 @@ data_path = %s
             "account_name = \n"
             "computer_title = \n"
             "https_proxy = \n"
+            "url = https://landscape.canonical.com/message-system\n"
+            "exchange_interval = 900\n"
+            "otp = \n"
+            "ping_interval = 30\n"
+            "ping_url = http://landscape.canonical.com/ping\n"
+            "provisioning_otp = \n"
+            "urgent_exchange_interval = 60\n"
              % config.data_path)
 
     def test_silent_setup_without_computer_title(self):
@@ -1331,7 +1372,8 @@ registration_key = shared-secret
             self.get_config(["--config", config_filename, "--silent",
                              "--import", import_filename])
         except ImportOptionError, error:
-            self.assertIn("File contains no section headers.", str(error))
+            self.assertIn("Nothing to import at %s" % import_filename,
+                          str(error))
         else:
             self.fail("ImportOptionError not raised")
 
@@ -1555,7 +1597,8 @@ registration_key = shared-secret
         try:
             self.get_config(["--silent", "--import", "https://config.url"])
         except ImportOptionError, error:
-            self.assertIn("File contains no section headers.", str(error))
+            self.assertEqual("Nothing to import at https://config.url.",
+                             str(error))
         else:
             self.fail("ImportOptionError not raised")
 
