@@ -1,10 +1,13 @@
 import sys
 import os
 from optparse import OptionParser
+from StringIO import StringIO
+from textwrap import dedent
 
 from landscape.deployment import Configuration, get_versioned_persist
+from landscape.manager.config import ManagerConfiguration
 
-from landscape.tests.helpers import LandscapeTest
+from landscape.tests.helpers import LandscapeTest, LogKeeperHelper
 from landscape.tests.mocker import ANY
 
 
@@ -20,6 +23,8 @@ class BabbleConfiguration(Configuration):
 
 class ConfigurationTest(LandscapeTest):
 
+    helpers = [LogKeeperHelper]
+
     def setUp(self):
         super(ConfigurationTest, self).setUp()
         self.reset_config()
@@ -27,7 +32,7 @@ class ConfigurationTest(LandscapeTest):
     def reset_config(self, configuration_class=None):
         if not configuration_class:
 
-            class MyConfiguration(Configuration):
+            class MyConfiguration(ManagerConfiguration):
                 default_config_filenames = []
             configuration_class = MyConfiguration
 
@@ -41,6 +46,26 @@ class ConfigurationTest(LandscapeTest):
         self.assertEqual(self.config.get("log_level"), "file")
         self.assertEqual(self.config.get("random_key"), None)
 
+    def test_get_config_object(self):
+        """
+        Calling L{get_config_object} returns a L{ConfigObj} bound to the
+        correct file and with its options set in the manor we expect.
+        """
+        config_obj = self.config._get_config_object()
+        self.assertEqual(self.config.get_config_filename(),
+                         config_obj.filename)
+        self.assertFalse(config_obj.list_values)
+
+    def test_get_config_object_with_alternative_config(self):
+        """
+        Calling L{get_config_object} with a the L{alternative_config} parameter
+        set, this source is used instead of calling through to
+        L{get_config_filename}.
+        """
+        config_obj = self.config._get_config_object(
+            alternative_config=StringIO("[client]\nlog_level = error\n"))
+        self.assertEqual(None, config_obj.filename)
+
     def write_config_file(self, **kwargs):
         section_name = kwargs.pop("section_name", "client")
         config = "\n".join(["[%s]" % (section_name,)] +
@@ -174,13 +199,65 @@ class ConfigurationTest(LandscapeTest):
         self.assertConfigEqual(data,
             "[client]\nlog_level = warning\n")
 
-    def test_dont_write_default_options(self):
+    def test_write_empty_list_values_instead_of_double_quotes(self):
+        """
+        Since list values are strings, an empty string such as C{""} will be
+        written to the config file as an option with a empty value instead of
+        C{""}.
+        """
+        self.write_config_file(include_manager_plugins="ScriptExecution")
+        self.config.load([])
+        self.config.include_manager_plugins = ""
+        self.config.write()
+        data = open(self.config_filename).read()
+        self.assertConfigEqual(data, "[client]\ninclude_manager_plugins = \n")
+
+    def test_dont_write_config_specified_default_options(self):
+        """
+        Don't write options to the file if the value exactly matches the
+        default and the value already existed in the original config file.
+        """
         self.write_config_file(log_level="debug")
         self.config.log_level = "info"
         self.config.write()
         data = open(self.config_filename).read()
         self.assertConfigEqual(data, "[client]")
 
+    def test_dont_write_unspecified_default_options(self):
+        """
+        Don't write options to the file if the value exactly matches the
+        default and the value did not exist in the original config file.
+        """
+        self.write_config_file()
+        self.config.log_level = "info"
+        self.config.write()
+        data = open(self.config_filename).read()
+        self.assertConfigEqual(data, "[client]")
+
+    def test_dont_write_client_section_default_options(self):
+        """
+        Don't write options to the file if they exactly match the default and
+        didn't already exist in the file.
+        """
+        self.write_config_file(log_level="debug")
+        self.config.log_level = "info"
+        self.config.write()
+        data = open(self.config_filename).read()
+        self.assertConfigEqual(data, "[client]")
+
+    def test_do_write_preexisting_default_options(self):
+        """
+        If the value of an option matches the default, but the option was
+        already written in the file, then write it back to the file.
+        """
+        config = "[client]\nlog_level = info\n"
+        config_filename = self.makeFile(config)
+        self.config.load_configuration_file(config_filename)
+        self.config.log_level = "info"
+        self.config.write()
+        data = open(config_filename).read()
+        self.assertConfigEqual(data, "[client]\nlog_level = info\n")
+
     def test_dont_delete_explicitly_set_default_options(self):
         """
         If the user explicitly sets a configuration option to its default
@@ -204,8 +281,7 @@ class ConfigurationTest(LandscapeTest):
         self.config.load(["--log-level", "warning"])
         self.config.write()
         data = open(self.config_filename).read()
-        self.assertConfigEqual(data,
-            "[client]\nlog_level = warning\n")
+        self.assertConfigEqual(data, "[client]\nlog_level = warning\n")
 
     def test_write_command_line_precedence(self):
         """Command line options take precedence over config file when writing.
@@ -214,8 +290,7 @@ class ConfigurationTest(LandscapeTest):
         self.config.load(["--log-level", "warning"])
         self.config.write()
         data = open(self.config_filename).read()
-        self.assertConfigEqual(data,
-            "[client]\nlog_level = warning\n")
+        self.assertConfigEqual(data, "[client]\nlog_level = warning\n")
 
     def test_write_manually_set_precedence(self):
         """Manually set options take precedence over command line when writing.
@@ -225,18 +300,32 @@ class ConfigurationTest(LandscapeTest):
         self.config.log_level = "error"
         self.config.write()
         data = open(self.config_filename).read()
-        self.assertConfigEqual(data,
-            "[client]\nlog_level = error\n")
+        self.assertConfigEqual(data, "[client]\nlog_level = error\n")
 
     def test_write_to_given_config_file(self):
         filename = self.makeFile()
-        self.config.load(["--log-level", "warning", "--config", filename],
-                         accept_nonexistent_config=True)
+        self.config.load(
+            ["--log-level", "warning", "--config", filename],
+            accept_nonexistent_config=True)
         self.config.log_level = "error"
         self.config.write()
         data = open(filename).read()
-        self.assertConfigEqual(data,
-            "[client]\nlog_level = error\n")
+        self.assertConfigEqual(data, "[client]\nlog_level = error\n")
+
+    def test_comments_are_maintained(self):
+        """
+        When we write an updated config file, comments that existed previously
+        are maintained.
+        """
+        config = "[client]\n# Comment 1\nlog_level = file\n#Comment 2\n"
+        filename = self.makeFile(config)
+        self.config.load_configuration_file(filename)
+        self.config.log_level = "error"
+        self.config.write()
+        new_config = open(filename).read()
+        self.assertConfigEqual(
+            new_config,
+            "[client]\n# Comment 1\nlog_level = error\n#Comment 2\n")
 
     def test_config_option(self):
         options = self.parser.parse_args(["--config", "hello.cfg"])[0]
@@ -282,6 +371,7 @@ class ConfigurationTest(LandscapeTest):
                 parser.add_option("--year", default=1, type="int")
                 return parser
 
+        self.write_config_file()
         config = MyConfiguration()
         config.load(["--year", "2008"])
         self.assertEqual(config.year, 2008)
@@ -297,7 +387,7 @@ class ConfigurationTest(LandscapeTest):
         self.config.reload()
         self.assertEqual(self.config.hello, "world2")
 
-    def test_load_cant_read(self):
+    def test_load_cannot_read(self):
         """
         C{config.load} exits the process if the specific config file can't be
         read because of permission reasons.
@@ -306,8 +396,55 @@ class ConfigurationTest(LandscapeTest):
         os.chmod(filename, 0)
         error = self.assertRaises(
             SystemExit, self.config.load, ["--config", filename])
-        self.assertEqual("error: config file %s can't be read" % filename,
-                         str(error))
+        self.assertEqual(
+            "error: config file %s can't be read" % filename, str(error))
+
+    def test_load_not_found(self):
+        """
+        C{config.load} exits the process if the specified config file is not
+        found.
+        """
+        filename = "/not/here"
+        error = self.assertRaises(
+            SystemExit, self.config.load, ["--config", filename])
+        self.assertEqual(
+            "error: config file %s can't be read" % filename, str(error))
+
+    def test_load_cannot_read_default(self):
+        """
+        C{config.load} exits the process if the default config file can't be
+        read because of permission reasons.
+        """
+        self.write_config_file()
+        [default] = self.config.default_config_filenames
+        os.chmod(default, 0)
+        error = self.assertRaises(SystemExit, self.config.load, [])
+        self.assertEqual(
+            "error: config file %s can't be read" % default, str(error))
+
+    def test_load_not_found_default(self):
+        """
+        C{config.load} exits the process if the default config file is not
+        found.
+        """
+        [default] = self.config.default_config_filenames[:] = ["/not/here"]
+        error = self.assertRaises(SystemExit, self.config.load, [])
+        self.assertEqual(
+            "error: config file %s can't be read" % default, str(error))
+
+    def test_load_cannot_read_many_defaults(self):
+        """
+        C{config.load} exits the process if none of the default config files
+        exists and can be read.
+        """
+        default1 = self.makeFile("")
+        default2 = self.makeFile("")
+        os.chmod(default1, 0)
+        os.unlink(default2)
+        self.config.default_config_filenames[:] = [default1, default2]
+
+        error = self.assertRaises(SystemExit, self.config.load, [])
+        self.assertEqual("error: no config file could be read", str(error))
 
     def test_data_directory_option(self):
         """Ensure options.data_path option can be read by parse_args."""
@@ -432,6 +569,7 @@ class ConfigurationTest(LandscapeTest):
 
     def test_clones_default(self):
         """By default, no clones are started."""
+        self.write_config_file()
         options = self.parser.parse_args([])[0]
         self.assertEqual(0, options.clones)
 
@@ -458,7 +596,7 @@ class ConfigurationTest(LandscapeTest):
 
         If a specific config file is requested, use this instead of defaults.
 
-        If a cmdilne --config option is specified this should take precedence
+        If a cmdline --config option is specified this should take precedence
         over either of the former options.
         """
         default_filename1 = self.makeFile("")
@@ -497,8 +635,9 @@ class ConfigurationTest(LandscapeTest):
         The L{Configuration.socket_path} property returns the path to the
         socket directory.
         """
-        self.assertEqual(self.config.sockets_path,
-                         "/var/lib/landscape/client/sockets")
+        self.assertEqual(
+            "/var/lib/landscape/client/sockets",
+            self.config.sockets_path)
 
     def test_annotations_path(self):
         """
@@ -509,14 +648,76 @@ class ConfigurationTest(LandscapeTest):
             "/var/lib/landscape/client/annotations.d",
             self.config.annotations_path)
 
+    def test_juju_filename(self):
+        """
+        The L{Configuration.juju_filename} property returns the path to the
+        juju info file.
+        """
+        self.assertEqual(
+            "/var/lib/landscape/client/juju-info.json",
+            self.config.juju_filename)
+
     def test_clone(self):
         """The L{Configuration.clone} method clones a configuration."""
+        self.write_config_file()
         self.config.load(["--data-path", "/some/path"])
         self.config.foo = "bar"
         config2 = self.config.clone()
         self.assertEqual(self.config.data_path, config2.data_path)
         self.assertEqual("bar", config2.foo)
 
+    def test_duplicate_key(self):
+        """
+        Duplicate keys in the config file shouldn't result in a fatal error,
+        but the first defined value should be used.
+        """
+        config = dedent("""
+        [client]
+        computer_title = frog
+        computer_title = flag
+        """)
+        filename = self.makeFile(config)
+        self.config.load_configuration_file(filename)
+        self.assertEqual("frog", self.config.computer_title)
+        self.assertIn("WARNING: Duplicate keyword name at line 4.",
+                      self.logfile.getvalue())
+
+    def test_triplicate_key(self):
+        """
+        Triplicate keys in the config file shouldn't result in a fatal error,
+        but the first defined value should be used.
+        """
+        config = dedent("""
+        [client]
+        computer_title = frog
+        computer_title = flag
+        computer_title = flop
+        """)
+        filename = self.makeFile(config)
+        self.config.load_configuration_file(filename)
+        self.assertEqual("frog", self.config.computer_title)
+        logged = self.logfile.getvalue()
+        self.assertIn("WARNING: Parsing failed with several errors.",
+                      logged)
+        self.assertIn("First error at line 4.", logged)
+
+    def test_config_values_after_fault_are_still_read(self):
+        """
+        Values that appear after the point in a configuration file where a
+        parsing error occurs are correctly parsed.
+        """
+        config = dedent("""
+        [client]
+        computer_title = frog
+        computer_title = flag
+        log_level = debug
+        """)
+        filename = self.makeFile(config)
+        self.config.load_configuration_file(filename)
+        self.assertEqual("debug", self.config.log_level)
+        self.assertIn("WARNING: Duplicate keyword name at line 4.",
+                      self.logfile.getvalue())
+
 
 class GetVersionedPersistTest(LandscapeTest):
 
