@@ -28,10 +28,9 @@ from landscape.lib.log import log_failure
 from landscape.lib.bootstrap import (BootstrapList, BootstrapFile,
                                      BootstrapDirectory)
 from landscape.log import rotate_logs
-from landscape.amp import ComponentProtocol
 from landscape.broker.amp import (
     RemoteBrokerConnector, RemoteMonitorConnector, RemoteManagerConnector)
-from landscape.reactor import TwistedReactor
+from landscape.reactor import LandscapeReactor
 from landscape.lib.dns import discover_server
 from landscape.configuration import (
     fetch_base64_ssl_public_certificate, decode_base64_ssl_public_certificate)
@@ -69,7 +68,7 @@ class Daemon(object):
     @cvar factor: The factor by which the delay between subsequent connection
         attempts will increase.
 
-    @param connector: The L{RemoteComponentConnector} of the daemon.
+    @param connector: The L{ComponentConnector} of the daemon.
     @param reactor: The reactor used to spawn the process and schedule timed
         calls.
     @param verbose: Optionally, report more information when running this
@@ -308,8 +307,8 @@ class WatchedProcessProtocol(ProcessProtocol):
         """The process has ended; restart it."""
         if self._delayed_really_kill is not None:
             self._delayed_really_kill.cancel()
-        if (self._delayed_terminate is not None
-            and self._delayed_terminate.active()):
+        if (self._delayed_terminate is not None and
+                self._delayed_terminate.active()):
             self._delayed_terminate.cancel()
         if self._wait_result is not None:
             self._wait_result.callback(None)
@@ -326,20 +325,20 @@ class WatchDog(object):
     def __init__(self, reactor=reactor, verbose=False, config=None,
                  broker=None, monitor=None, manager=None,
                  enabled_daemons=None):
-        twisted_reactor = TwistedReactor()
+        landscape_reactor = LandscapeReactor()
         if enabled_daemons is None:
             enabled_daemons = [Broker, Monitor, Manager]
         if broker is None and Broker in enabled_daemons:
             broker = Broker(
-                RemoteBrokerConnector(twisted_reactor, config),
+                RemoteBrokerConnector(landscape_reactor, config),
                 verbose=verbose, config=config.config)
         if monitor is None and Monitor in enabled_daemons:
             monitor = Monitor(
-                RemoteMonitorConnector(twisted_reactor, config),
+                RemoteMonitorConnector(landscape_reactor, config),
                 verbose=verbose, config=config.config)
         if manager is None and Manager in enabled_daemons:
             manager = Manager(
-                RemoteManagerConnector(twisted_reactor, config),
+                RemoteManagerConnector(landscape_reactor, config),
                 verbose=verbose, config=config.config)
 
         self.broker = broker
@@ -349,7 +348,10 @@ class WatchDog(object):
         self.reactor = reactor
         self._checking = None
         self._stopping = False
-        signal.signal(signal.SIGUSR1, self._notify_rotate_logs)
+        signal.signal(
+            signal.SIGUSR1,
+            lambda signal, frame: reactor.callFromThread(
+                self._notify_rotate_logs))
         if config is not None and config.clones > 0:
             options = ["--clones", str(config.clones),
                        "--start-clones-over", str(config.start_clones_over)]
@@ -448,7 +450,7 @@ class WatchDog(object):
         result = self.broker.request_exit()
         return result.addCallback(terminate_processes)
 
-    def _notify_rotate_logs(self, signal, frame):
+    def _notify_rotate_logs(self):
         for daemon in self.daemons:
             daemon.rotate_logs()
         rotate_logs()
@@ -552,8 +554,11 @@ class WatchDogService(Service):
             setrlimit(RLIMIT_NOFILE, (self._config.clones * 100,
                                       self._config.clones * 200))
 
-            # Increase the timeout of AMP's MethodCalls
-            ComponentProtocol.timeout = 300
+            # Increase the timeout of AMP's MethodCalls.
+            # XXX: we should find a better way to expose this knot, and
+            # not set it globally on the class
+            from landscape.lib.amp import MethodCallSender
+            MethodCallSender.timeout = 300
 
             # Create clones log and data directories
             for i in range(self._config.clones):
@@ -630,8 +635,7 @@ bootstrap_list = BootstrapList([
     BootstrapDirectory(
         "$data_path/custom-graph-scripts", "landscape", "root", 0755),
     BootstrapDirectory("$log_dir", "landscape", "root", 0755),
-    BootstrapFile("$data_path/package/database", "landscape", "root", 0644),
-    ])
+    BootstrapFile("$data_path/package/database", "landscape", "root", 0644)])
 
 
 def clean_environment():
@@ -643,9 +647,8 @@ def clean_environment():
     *other* maintainer scripts which landscape-client invokes.
     """
     for key in os.environ.keys():
-        if (key.startswith("DEBIAN_")
-            or key.startswith("DEBCONF_")
-            or key in ["LANDSCAPE_ATTACHMENTS", "MAIL"]):
+        if (key.startswith(("DEBIAN_", "DEBCONF_")) or
+                key in ["LANDSCAPE_ATTACHMENTS", "MAIL"]):
             del os.environ[key]
 
 
